Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports CADImport
Imports CADImport.FaceModule
Imports CADImport.CADImportForms
''' <summary>
''' Represents a form in which the properties of the multiline text are set 
''' before adding it to the current CAD image.
''' </summary>
Public Class AddMTextForm
    Inherits Form
    ' Events
    Public Event ResizeImageEvent As CADImportEventHandler

    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="!:AddEntityDemoApplication.AddMTextForm">AddMTextForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitializeComponent()
        Me.InitExtParam()
    End Sub

    Private Sub btnAdd_Click(ByVal sender As Object, ByVal e As EventArgs)
        Dim attrib As String = String.Empty
        If (Me.bValue = ApplicationConstants.onestr3) Then
            attrib = ApplicationConstants.boldstr
        Else
            attrib = ApplicationConstants.regularstr
        End If
        If (Me.iValue = ApplicationConstants.onestr3) Then
            attrib = (attrib & ApplicationConstants.italicstr)
        End If
        If (Me.uValue = ApplicationConstants.lstr2) Then
            attrib = (attrib & ApplicationConstants.underlinedstr)
        End If
        attrib = (attrib & ApplicationConstants.sepstr4)
        Me.attributes.Add(attrib)
        Me.colors.Add(Me.tbColor.BackColor)
        Me.fonts.Add(Me.fName)
        Me.textValue = Me.rchText.Text
        Me.template = String.Format("\f{0}|b{1}|i{2};\H{3};\{4}\C{5};{6}\P", New Object() {Me.fName, Me.bValue, Me.iValue, Me.hValue, Me.uValue, Me.cValue, Me.textValue})
        Me.strings.Add(Me.template)
        Me.lstMText.Items.Add(Me.rchText.Text)
    End Sub

    Private Sub btnCancel_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.DialogResult = DialogResult.Cancel
        MyBase.Close()
    End Sub

    Private Sub btnOK_Click(ByVal sender As Object, ByVal e As EventArgs)
        Dim res As String = String.Empty
        Try
            Dim i As Integer
            For i = 0 To Me.strings.Count - 1
                res = (res & Me.strings.Item(i).ToString)
            Next i
            res = ("{" & res & "}")
            Me.mText.Point = New DPoint(Convert.ToDouble(Me.tbX.Text), Convert.ToDouble(Me.tbY.Text), Convert.ToDouble(Me.tbZ.Text))
            Me.mText.Angle = Convert.ToInt32(Me.tbRotation.Text)
            Me.mText.Text = res
            Me.cadImage.Converter.GetSection(ConvSection.Entities).AddEntity(Me.mText)
            Me.cadImage.Converter.OnCreate(Me.mText)
            Me.cadImage.Converter.Loads(Me.mText)
            Me.cadImage.GetExtents()
            Me.OnResizeImage()
        Catch exception As FormatException
            MessageBox.Show(exception.Message, ApplicationConstants.appnamestr, MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        End Try
        MyBase.DialogResult = DialogResult.OK
        MyBase.Close()
    End Sub

    Private Sub btnPickColor_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cSelector = New ColorSelector(Me.colorIndex)
        Me.cSelector.ShowDialog()
        If (Me.cSelector.DialogResult = DialogResult.OK) Then
            Me.tbColor.BackColor = Color.FromArgb(Me.cSelector.R, Me.cSelector.G, Me.cSelector.B)
            Me.rchText.ForeColor = Me.tbColor.BackColor
            Me.colorIndex = Me.cSelector.ColorIndex
            Me.cValue = Me.colorIndex.ToString
        End If
    End Sub

    Private Sub btnRemove_Click(ByVal sender As Object, ByVal e As EventArgs)
        Dim n As Integer = 0
        If (Me.lstMText.SelectedIndex >= 0) Then
            n = Me.lstMText.SelectedIndex
            Me.strings.RemoveAt(n)
            Me.lstMText.Items.RemoveAt(n)
            Me.attributes.RemoveAt(n)
            Me.colors.RemoveAt(n)
            Me.fonts.RemoveAt(n)
        End If
    End Sub

    Private Sub btnSelectFont_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Me.fDialog.ShowDialog = DialogResult.OK) Then
            Me.tbSelectedFont.Text = Me.fDialog.Font.Name
            If (Not Me.mText Is Nothing) Then
                Me.fName = Me.fDialog.Font.Name
                If Me.fDialog.Font.Bold Then
                    Me.bValue = ApplicationConstants.onestr3
                Else
                    Me.bValue = ApplicationConstants.zerostr
                End If
                If Me.fDialog.Font.Italic Then
                    Me.iValue = ApplicationConstants.onestr3
                Else
                    Me.iValue = ApplicationConstants.onestr3
                End If
                If Me.fDialog.Font.Underline Then
                    Me.uValue = ApplicationConstants.lstr2
                Else
                    Me.uValue = ApplicationConstants.lstr
                End If
                Me.hValue = Me.fDialog.Font.Height.ToString
                Me.rchText.Font = Me.fDialog.Font
            End If
        End If
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

    Private Sub InitExtParam()
        Me.fName = ApplicationConstants.font1str
        Me.bValue = ApplicationConstants.zerostr
        Me.iValue = ApplicationConstants.zerostr
        Me.hValue = ApplicationConstants.onestr2
        Me.uValue = ApplicationConstants.lstr
        Me.cValue = ApplicationConstants.zerostr
        Me.mTextList = New ArrayList
        Me.strings = New ArrayList
        Me.attributes = New ArrayList
        Me.colors = New ArrayList
        Me.fonts = New ArrayList
        Me.fDialog = New FontDialog
        Me.mText = New CADMText
        Me.textValue = String.Empty
        Me.setColorDlg = New ColorDialog
        Me.setColorDlg.SolidColorOnly = True
        MyBase.StartPosition = FormStartPosition.CenterScreen
        Me.colorIndex = 0
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Me.btPickColor = New Button
        Me.lbColor = New Label
        Me.line5 = New Label
        Me.line4 = New Label
        Me.line3 = New Label
        Me.line2 = New Label
        Me.line1 = New Label
        Me.lbY = New Label
        Me.lbZ = New Label
        Me.lbX = New Label
        Me.tbZ = New TextBox
        Me.tbY = New TextBox
        Me.tbX = New TextBox
        Me.vertLine2 = New Label
        Me.vertLine1 = New Label
        Me.lbFirst = New Label
        Me.btOK = New Button
        Me.tbRotation = New TextBox
        Me.lbText = New Label
        Me.label2 = New Label
        Me.btSelectFont = New Button
        Me.tbSelectedFont = New TextBox
        Me.label3 = New Label
        Me.lstMText = New ListBox
        Me.btAdd = New Button
        Me.rchText = New RichTextBox
        Me.btRemove = New Button
        Me.tbColorText = New TextBox
        Me.lbTextAttributes = New Label
        Me.lbColorText = New Label
        Me.lbFontName = New Label
        Me.lbFontStyle = New Label
        Me.lbFont = New Label
        Me.lbAttributes = New Label
        Me.label8 = New Label
        Me.tbColor = New Label
        Me.lbRotation = New Label
        Me.btCancel = New Button
        MyBase.SuspendLayout()
        Me.btPickColor.FlatStyle = FlatStyle.System
        Me.btPickColor.Location = New Point(&H80, &H40)
        Me.btPickColor.Name = "btPickColor"
        Me.btPickColor.Size = New Size(&H5F, &H19)
        Me.btPickColor.TabIndex = 10
        Me.btPickColor.Text = "Pick a color"
        AddHandler Me.btPickColor.Click, New System.EventHandler(AddressOf Me.btnPickColor_Click)
        Me.lbColor.FlatStyle = FlatStyle.System
        Me.lbColor.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbColor.Location = New Point(8, &H48)
        Me.lbColor.Name = "lbColor"
        Me.lbColor.Size = New Size(&H30, &H17)
        Me.lbColor.TabIndex = 8
        Me.lbColor.Text = "Color :"
        Me.line5.BackColor = Color.Black
        Me.line5.Location = New Point(8, 280)
        Me.line5.Name = "line5"
        Me.line5.Size = New Size(&HD4, 1)
        Me.line5.TabIndex = &H25
        Me.line4.BackColor = Color.Black
        Me.line4.Location = New Point(8, &HF8)
        Me.line4.Name = "line4"
        Me.line4.Size = New Size(&HD4, 1)
        Me.line4.TabIndex = &H24
        Me.line3.BackColor = Color.Black
        Me.line3.Location = New Point(8, &HD8)
        Me.line3.Name = "line3"
        Me.line3.Size = New Size(&HD4, 1)
        Me.line3.TabIndex = &H23
        Me.line2.BackColor = Color.Black
        Me.line2.Location = New Point(8, &HB8)
        Me.line2.Name = "line2"
        Me.line2.Size = New Size(&HD4, 1)
        Me.line2.TabIndex = &H22
        Me.line1.BackColor = Color.Black
        Me.line1.Location = New Point(8, 160)
        Me.line1.Name = "line1"
        Me.line1.Size = New Size(&HD4, 1)
        Me.line1.TabIndex = &H21
        Me.lbY.FlatStyle = FlatStyle.System
        Me.lbY.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbY.Location = New Point(8, &HE0)
        Me.lbY.Name = "lbY"
        Me.lbY.Size = New Size(&H62, 20)
        Me.lbY.TabIndex = &H27
        Me.lbY.Text = "Y coordinate :"
        Me.lbY.TextAlign = ContentAlignment.MiddleCenter
        Me.lbZ.FlatStyle = FlatStyle.System
        Me.lbZ.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbZ.Location = New Point(8, &H100)
        Me.lbZ.Name = "lbZ"
        Me.lbZ.Size = New Size(&H62, 20)
        Me.lbZ.TabIndex = 40
        Me.lbZ.Text = "Z coordinate :"
        Me.lbZ.TextAlign = ContentAlignment.MiddleCenter
        Me.lbX.FlatStyle = FlatStyle.System
        Me.lbX.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbX.Location = New Point(8, &HC0)
        Me.lbX.Name = "lbX"
        Me.lbX.Size = New Size(&H62, 20)
        Me.lbX.TabIndex = &H26
        Me.lbX.Text = "X coordinate :"
        Me.lbX.TextAlign = ContentAlignment.MiddleCenter
        Me.tbZ.Location = New Point(&H70, &H100)
        Me.tbZ.Name = "tbZ"
        Me.tbZ.TabIndex = &H2B
        Me.tbZ.Text = "0,0"
        Me.tbY.Location = New Point(&H70, &HE0)
        Me.tbY.Name = "tbY"
        Me.tbY.TabIndex = &H2A
        Me.tbY.Text = "0,0"
        Me.tbX.Location = New Point(&H70, &HC0)
        Me.tbX.Name = "tbX"
        Me.tbX.TabIndex = &H29
        Me.tbX.Text = "0,0"
        Me.vertLine2.BackColor = Color.Black
        Me.vertLine2.Location = New Point(220, 160)
        Me.vertLine2.Name = "vertLine2"
        Me.vertLine2.Size = New Size(1, 120)
        Me.vertLine2.TabIndex = &H2D
        Me.vertLine1.BackColor = Color.Black
        Me.vertLine1.Location = New Point(&H68, 160)
        Me.vertLine1.Name = "vertLine1"
        Me.vertLine1.Size = New Size(1, 120)
        Me.vertLine1.TabIndex = &H2C
        Me.lbFirst.FlatStyle = FlatStyle.System
        Me.lbFirst.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFirst.Location = New Point(&H70, 160)
        Me.lbFirst.Name = "lbFirst"
        Me.lbFirst.Size = New Size(&H44, &H10)
        Me.lbFirst.TabIndex = &H2E
        Me.lbFirst.Text = "Start point"
        Me.btOK.FlatStyle = FlatStyle.System
        Me.btOK.Location = New Point(&H128, &H120)
        Me.btOK.Name = "btOK"
        Me.btOK.Size = New Size(&H4B, &H19)
        Me.btOK.TabIndex = &H2F
        Me.btOK.Text = "OK"
        AddHandler Me.btOK.Click, New System.EventHandler(AddressOf Me.btnOK_Click)
        Me.tbRotation.Location = New Point(8, &H80)
        Me.tbRotation.Name = "tbRotation"
        Me.tbRotation.Size = New Size(&H68, 20)
        Me.tbRotation.TabIndex = &H31
        Me.tbRotation.Text = "0"
        Me.lbText.FlatStyle = FlatStyle.System
        Me.lbText.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbText.Location = New Point(240, &H60)
        Me.lbText.Name = "lbText"
        Me.lbText.Size = New Size(&H60, &H17)
        Me.lbText.TabIndex = &H34
        Me.lbText.Text = "Text contents :"
        Me.label2.FlatStyle = FlatStyle.System
        Me.label2.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.label2.Location = New Point(8, 8)
        Me.label2.Name = "label2"
        Me.label2.Size = New Size(40, &H17)
        Me.label2.TabIndex = &H36
        Me.label2.Text = "Font :"
        Me.btSelectFont.FlatStyle = FlatStyle.System
        Me.btSelectFont.Font = New Font("Microsoft Sans Serif", 8.25!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.btSelectFont.Location = New Point(&H80, &H20)
        Me.btSelectFont.Name = "btSelectFont"
        Me.btSelectFont.Size = New Size(&H5F, &H19)
        Me.btSelectFont.TabIndex = &H37
        Me.btSelectFont.Text = "Select"
        AddHandler Me.btSelectFont.Click, New System.EventHandler(AddressOf Me.btnSelectFont_Click)
        Me.tbSelectedFont.BackColor = Color.White
        Me.tbSelectedFont.Font = New Font("Microsoft Sans Serif", 9.0!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.tbSelectedFont.Location = New Point(8, &H20)
        Me.tbSelectedFont.Multiline = True
        Me.tbSelectedFont.Name = "tbSelectedFont"
        Me.tbSelectedFont.ReadOnly = True
        Me.tbSelectedFont.Size = New Size(&H68, &H16)
        Me.tbSelectedFont.TabIndex = &H38
        Me.tbSelectedFont.Text = "Microsoft Sans Serif"
        Me.label3.FlatStyle = FlatStyle.System
        Me.label3.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.label3.Location = New Point(240, 8)
        Me.label3.Name = "label3"
        Me.label3.Size = New Size(&H68, &H17)
        Me.label3.TabIndex = &H39
        Me.label3.Text = "Enter a text line :"
        Me.lstMText.BackColor = SystemColors.ActiveCaptionText
        Me.lstMText.Location = New Point(240, 120)
        Me.lstMText.Name = "lstMText"
        Me.lstMText.Size = New Size(&HD0, &H38)
        Me.lstMText.TabIndex = &H3A
        AddHandler Me.lstMText.SelectedIndexChanged, New System.EventHandler(AddressOf Me.lstMText_SelectedIndexChanged)
        Me.btAdd.FlatStyle = FlatStyle.System
        Me.btAdd.Location = New Point(240, &H40)
        Me.btAdd.Name = "btAdd"
        Me.btAdd.Size = New Size(&H5F, &H19)
        Me.btAdd.TabIndex = &H3B
        Me.btAdd.Text = "Add"
        AddHandler Me.btAdd.Click, New System.EventHandler(AddressOf Me.btnAdd_Click)
        Me.rchText.Location = New Point(240, &H20)
        Me.rchText.Multiline = False
        Me.rchText.Name = "rchText"
        Me.rchText.Size = New Size(&HD0, 20)
        Me.rchText.TabIndex = 60
        Me.rchText.Text = ""
        Me.btRemove.FlatStyle = FlatStyle.System
        Me.btRemove.Location = New Point(&H160, &H40)
        Me.btRemove.Name = "btRemove"
        Me.btRemove.Size = New Size(&H5F, &H19)
        Me.btRemove.TabIndex = &H3D
        Me.btRemove.Text = "Remove"
        AddHandler Me.btRemove.Click, New System.EventHandler(AddressOf Me.btnRemove_Click)
        Me.tbColorText.BackColor = Color.Black
        Me.tbColorText.Enabled = False
        Me.tbColorText.Location = New Point(&H120, &HD8)
        Me.tbColorText.Multiline = True
        Me.tbColorText.Name = "tbColorText"
        Me.tbColorText.Size = New Size(40, &H17)
        Me.tbColorText.TabIndex = &H3E
        Me.tbColorText.Text = ""
        Me.lbTextAttributes.FlatStyle = FlatStyle.System
        Me.lbTextAttributes.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbTextAttributes.Location = New Point(240, &HC0)
        Me.lbTextAttributes.Name = "lbTextAttributes"
        Me.lbTextAttributes.Size = New Size(&HD8, &H12)
        Me.lbTextAttributes.TabIndex = &H3F
        Me.lbTextAttributes.Text = "Attributes of the selected text line :"
        Me.lbColorText.FlatStyle = FlatStyle.System
        Me.lbColorText.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbColorText.Location = New Point(240, &HD8)
        Me.lbColorText.Name = "lbColorText"
        Me.lbColorText.Size = New Size(&H2C, &H12)
        Me.lbColorText.TabIndex = &H40
        Me.lbColorText.Text = "Color :"
        Me.lbFontName.FlatStyle = FlatStyle.System
        Me.lbFontName.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFontName.Location = New Point(240, &H108)
        Me.lbFontName.Name = "lbFontName"
        Me.lbFontName.Size = New Size(&H4E, &H12)
        Me.lbFontName.TabIndex = &H42
        Me.lbFontName.Text = "Font name :"
        Me.lbFontStyle.FlatStyle = FlatStyle.System
        Me.lbFontStyle.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFontStyle.Location = New Point(240, 240)
        Me.lbFontStyle.Name = "lbFontStyle"
        Me.lbFontStyle.Size = New Size(&H4E, &H12)
        Me.lbFontStyle.TabIndex = &H43
        Me.lbFontStyle.Text = "Font style :"
        Me.lbFont.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbFont.Location = New Point(&H138, &H108)
        Me.lbFont.Name = "lbFont"
        Me.lbFont.Size = New Size(&H98, &H12)
        Me.lbFont.TabIndex = &H44
        Me.lbFont.TextAlign = ContentAlignment.MiddleLeft
        Me.lbAttributes.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbAttributes.Location = New Point(&H138, 240)
        Me.lbAttributes.Name = "lbAttributes"
        Me.lbAttributes.Size = New Size(&H90, &H12)
        Me.lbAttributes.TabIndex = &H41
        Me.lbAttributes.TextAlign = ContentAlignment.MiddleLeft
        Me.label8.BackColor = Color.Black
        Me.label8.Location = New Point(8, 160)
        Me.label8.Name = "label8"
        Me.label8.Size = New Size(1, &H79)
        Me.label8.TabIndex = &H45
        Me.tbColor.BackColor = Color.Black
        Me.tbColor.BorderStyle = BorderStyle.Fixed3D
        Me.tbColor.Location = New Point(&H40, &H47)
        Me.tbColor.Name = "tbColor"
        Me.tbColor.Size = New Size(&H30, &H17)
        Me.tbColor.TabIndex = 70
        AddHandler Me.tbColor.Click, New System.EventHandler(AddressOf Me.tbColor_Click)
        Me.lbRotation.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbRotation.Location = New Point(8, &H68)
        Me.lbRotation.Name = "lbRotation"
        Me.lbRotation.TabIndex = &H47
        Me.lbRotation.Text = "Rotation angle:"
        Me.btCancel.FlatStyle = FlatStyle.System
        Me.btCancel.Location = New Point(&H178, &H120)
        Me.btCancel.Name = "btCancel"
        Me.btCancel.Size = New Size(&H4B, &H19)
        Me.btCancel.TabIndex = &H48
        Me.btCancel.Text = "Cancel"
        AddHandler Me.btCancel.Click, New System.EventHandler(AddressOf Me.btnCancel_Click)
        Me.AutoScaleBaseSize = New Size(5, 13)
        MyBase.ClientSize = New Size(&H1CA, &H13D)
        MyBase.Controls.Add(Me.btCancel)
        MyBase.Controls.Add(Me.lbRotation)
        MyBase.Controls.Add(Me.tbColor)
        MyBase.Controls.Add(Me.label8)
        MyBase.Controls.Add(Me.lbFont)
        MyBase.Controls.Add(Me.lbFontStyle)
        MyBase.Controls.Add(Me.lbFontName)
        MyBase.Controls.Add(Me.lbAttributes)
        MyBase.Controls.Add(Me.lbColorText)
        MyBase.Controls.Add(Me.lbTextAttributes)
        MyBase.Controls.Add(Me.tbColorText)
        MyBase.Controls.Add(Me.tbSelectedFont)
        MyBase.Controls.Add(Me.tbRotation)
        MyBase.Controls.Add(Me.tbZ)
        MyBase.Controls.Add(Me.tbY)
        MyBase.Controls.Add(Me.tbX)
        MyBase.Controls.Add(Me.btRemove)
        MyBase.Controls.Add(Me.btAdd)
        MyBase.Controls.Add(Me.lstMText)
        MyBase.Controls.Add(Me.label3)
        MyBase.Controls.Add(Me.btSelectFont)
        MyBase.Controls.Add(Me.label2)
        MyBase.Controls.Add(Me.lbText)
        MyBase.Controls.Add(Me.btOK)
        MyBase.Controls.Add(Me.vertLine2)
        MyBase.Controls.Add(Me.vertLine1)
        MyBase.Controls.Add(Me.lbY)
        MyBase.Controls.Add(Me.lbZ)
        MyBase.Controls.Add(Me.lbX)
        MyBase.Controls.Add(Me.line5)
        MyBase.Controls.Add(Me.line4)
        MyBase.Controls.Add(Me.line3)
        MyBase.Controls.Add(Me.line2)
        MyBase.Controls.Add(Me.line1)
        MyBase.Controls.Add(Me.btPickColor)
        MyBase.Controls.Add(Me.lbColor)
        MyBase.Controls.Add(Me.rchText)
        MyBase.Controls.Add(Me.lbFirst)
        MyBase.FormBorderStyle = FormBorderStyle.FixedSingle
        MyBase.MaximizeBox = False
        MyBase.Name = "AddMTextForm"
        MyBase.StartPosition = FormStartPosition.CenterParent
        Me.Text = "Add MText"
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Private Sub lstMText_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs)
        If (Not DirectCast(sender, ListBox).SelectedItem Is Nothing) Then
            Me.rchText.Text = DirectCast(sender, ListBox).SelectedItem.ToString
            Me.lbAttributes.Text = Me.attributes.Item(DirectCast(sender, ListBox).SelectedIndex).ToString
            Me.tbColorText.BackColor = DirectCast(Me.colors.Item(DirectCast(sender, ListBox).SelectedIndex), Color)
            Me.lbFont.Text = Me.fonts.Item(DirectCast(sender, ListBox).SelectedIndex).ToString
        End If
    End Sub

    Public Sub OnResizeImage()
        'If (Not Me.ResizeImageEvent Is Nothing) Then
            RaiseEvent ResizeImageEvent()
        'End If
    End Sub

    Private Sub tbColor_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cSelector = New ColorSelector(Me.colorIndex)
        Me.cSelector.ShowDialog()
        If (Me.cSelector.DialogResult = DialogResult.OK) Then
            Me.tbColor.BackColor = Color.FromArgb(Me.cSelector.R, Me.cSelector.G, Me.cSelector.B)
            Me.rchText.ForeColor = Me.tbColor.BackColor
            Me.colorIndex = Me.cSelector.ColorIndex
            Me.cValue = Me.colorIndex.ToString
        End If
    End Sub


    ' Properties
    Public Property Image() As CADImage
        Get
            Return Me.cadImage
        End Get
        Set(ByVal value As CADImage)
            Me.cadImage = value
        End Set
    End Property


    ' Fields
    Private attributes As ArrayList
    Private btAdd As Button
    Private btCancel As Button
    Private btOK As Button
    Private btPickColor As Button
    Private btRemove As Button
    Private btSelectFont As Button
    Private bValue As String
    Private cadImage As CADImage
    Private colorIndex As Byte
    Private colors As ArrayList
    Private components As Container = Nothing
    Private cSelector As ColorSelector
    Private cValue As String
    Private fDialog As FontDialog
    Private fName As String
    Private fonts As ArrayList
    Private hValue As String
    Private iValue As String
    Private label2 As Label
    Private label3 As Label
    Private label8 As Label
    Private lbAttributes As Label
    Private lbColor As Label
    Private lbColorText As Label
    Private lbFirst As Label
    Private lbFont As Label
    Private lbFontName As Label
    Private lbFontStyle As Label
    Private lbRotation As Label
    Private lbText As Label
    Private lbTextAttributes As Label
    Private lbX As Label
    Private lbY As Label
    Private lbZ As Label
    Private line1 As Label
    Private line2 As Label
    Private line3 As Label
    Private line4 As Label
    Private line5 As Label
    Private lstMText As ListBox
    Private mText As CADMText
    Private mTextList As ArrayList
    Private rchText As RichTextBox
    Private setColorDlg As ColorDialog
    Private strings As ArrayList
    Private tbColor As Label
    Private tbColorText As TextBox
    Private tbRotation As TextBox
    Private tbSelectedFont As TextBox
    Private tbX As TextBox
    Private tbY As TextBox
    Private tbZ As TextBox
    Private template As String
    Private textValue As String
    Private uValue As String
    Private vertLine1 As Label
    Private vertLine2 As Label
End Class

