Imports System
Imports System.IO
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports System.Resources
Imports System.Data
Imports System.Globalization
Imports System.Drawing.Imaging
Imports System.Drawing.Drawing2D
Imports System.Runtime.Serialization
Imports System.Runtime.Serialization.Formatters.Binary
Imports CADImport
Imports CADImport.CADImportForms
Imports CADImport.FaceModule
Imports CADImport.RasterImage
Imports CADImport.Professional
Imports CADImport.HPGL2

Public Class MainForm
    Inherits Form
    ' Methods
    Public Sub New()
        Me.InitParams()
        Me.InitialCADImportForms()
        Me.InitializeComponent()
        Me.InitParamsState()
        Me.InitLng()
        Me.InitSettings()
        Me.SetAllFormsSettings()
    End Sub

    <System.STAThread()> _
    Public Shared Sub Main()
        Application.EnableVisualStyles()
        Application.DoEvents()
        Application.Run(New MainForm)
    End Sub

    Private Sub AddRecordToLayerList(ByVal name As String, ByVal color As Color, ByVal visible As Boolean, ByVal freeze As Boolean)
        Dim lstItem As New ListItem
        lstItem.Text = name
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        If visible Then
            lstItem.ImageIndex = 7
        Else
            lstItem.ImageIndex = 8
        End If
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        If freeze Then
            lstItem.ImageIndex = 3
        Else
            lstItem.ImageIndex = 4
        End If
        Me.lForm.LayerList.Items.Add(lstItem)
        lstItem = New ListItem
        lstItem.DrawColorRect = True
        lstItem.BackColor = color
        Me.lForm.LayerList.Items.Add(lstItem)
    End Sub

    Public Sub Black_Click()
        Me.cadPictBox.BackColor = Color.Black
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.BackgroundColor = Color.Black
        End If
        Me.trvEntity.BackColor = Color.Black
        Me.trvEntity.ForeColor = Color.White
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.DefaultColor = Color.White
        End If
        If (Not Me.clipRectangle Is Nothing) Then
            Me.clipRectangle.Color = Color.White
        End If
    End Sub

    Private Sub SetAllFormsSettings()
        Me.SetAllFormsLanguageSettings()
        AddHandler Me.entCreator.OptionsForm.ChangeLngPath, New ChangeLngPathEventHandler(AddressOf Me.ReloadLNG)
        AddHandler Me.entCreator.OptionsForm.ChangeLanguage, New ChangeLanguageEventHandler(AddressOf Me.ChangeLanguage)
    End Sub

    Private Sub cadPictBox_MouseDown(ByVal sender As Object, ByVal e As MouseEventArgs)
        If (e.Button <> MouseButtons.Right) Then
            If Not Me.CreateNewEntity Then
                Me.DisableEntityCreator()
            End If
            If ((Not Me.cadImage Is Nothing) AndAlso (Me.cadImage.SelectionMode = SelectionEntityMode.Enabled)) Then
                If Me.SelectEntity(e.X, e.Y) Then
                    Return
                End If
                If ((Not Me.cadImage.SelectedEntities Is Nothing) AndAlso Not Me.CreateNewEntity) Then
                    Me.cadImage.InvalidateSelectEntity(Me.cadPictBox, Me.ImageScale)
                End If
            End If
        End If
        Me.cX = e.X
        Me.cY = e.Y
        Me.detMouseDown = True
        If ((Not Me.CreateNewEntity OrElse Not Me.EnableNewEntityCreator) AndAlso ((e.Button = MouseButtons.Left) AndAlso Not Me.moveMarker)) Then
            Me.clipRectangle.EnableRect(RectangleType.Zooming, New Rectangle(e.X, e.Y, 0, 0))
        End If
    End Sub

    Private Sub cadPictBox_MouseMove(ByVal sender As Object, ByVal e As MouseEventArgs)
        If (Not Me.cadImage Is Nothing) Then
            If Not Me.cadPictBox.Focused Then
                Me.cadPictBox.Focus()
                Me.cadPictBox.Invalidate()
            End If
            If (Not Me.stopSnap AndAlso Me.cadPictBox.ClientRectangle.Contains(e.X, e.Y)) Then
                Dim tmpRect As RectangleF = Me.ImageRectangleF
                Me.cadImage.DrawSnapTrace(e.X, e.Y, Me.cadPictBox, tmpRect)
            Else
                Me.cadImage.RefreshSnapTrace(Me.cadPictBox)
                Me.stopSnap = False
            End If
            If Me.detMouseDown Then
                If ((e.Button <> MouseButtons.Right) AndAlso Me.ChangeEntityOnMouseMove(New Point(e.X, e.Y))) Then
                    Return
                End If
                If (Not Me.clipRectangle.Enabled AndAlso Not Me.CreateNewEntity) Then
                    Me.LeftImagePosition = (Me.LeftImagePosition - (Me.cX - e.X))
                    Me.TopImagePosition = (Me.TopImagePosition - (Me.cY - e.Y))
                    Me.cadPictBox.Invalidate()
                    Me.SetPictureBoxPosition(Me.Position)
                End If
                Me.cX = e.X
                Me.cY = e.Y
            End If
            Me.PreviousPosition = New PointF(CSng(e.X), CSng(e.Y))
            Dim vPt As DPoint = Me.GetRealPoint(e.X, e.Y)
            Me.stBar.Panels.Item(2).Text = String.Format("{0} : {1} : 0", vPt.X, vPt.Y)
        End If
    End Sub

    Private Sub cadPictBox_MouseUp(ByVal sender As Object, ByVal e As MouseEventArgs)
        If (Not Me.cadImage Is Nothing) Then
            If (e.Button <> MouseButtons.Right) Then
                Me.ChangeEntityOnMouseUp(New Point(e.X, e.Y))
            End If
            Me.detMouseDown = False
            If (Me.clipRectangle.Enabled AndAlso (Me.clipRectangle.Type = RectangleType.Zooming)) Then
                Me.UseClipRect()
            End If
            If Not Me.CreateNewEntity Then
                Me.stopSnap = True
                Me.cadPictBox.Invalidate()
            End If
        End If
    End Sub

    Private Sub cadPictBox_Paint(ByVal sender As Object, ByVal e As PaintEventArgs)
        Me.DrawCADImage(e.Graphics)
        Me.stBar.Panels.Item(1).Text = Me.RealScale
    End Sub

    Private Sub CADPictBoxKeyDown(ByVal sender As Object, ByVal e As KeyEventArgs)
        If Not Me.cadPictBox.Focused Then
            Me.cadPictBox.Focus()
        End If
        Dim cn As Integer = 2
        If e.Shift Then
            cn = 5
        End If
        Select Case e.KeyCode
            Case Keys.Return
                Me.entCreator.EndEntity()
                Exit Select
            Case Keys.ShiftKey, Keys.ControlKey
                Me.cntrlDown = True
                Exit Select
            Case Keys.Escape
                Me.ClearSelection()
                Exit Select
            Case Keys.Left
                Me.MoveEntity(cn, 0, cn, 0)
                Exit Select
            Case Keys.Up
                Me.MoveEntity(0, cn, 0, cn)
                Exit Select
            Case Keys.Right
                Me.MoveEntity(-cn, 0, -cn, 0)
                Exit Select
            Case Keys.Down
                Me.MoveEntity(0, -cn, 0, -cn)
                Exit Select
        End Select
    End Sub

    Private Sub CADPictBoxKeyUp(ByVal sender As Object, ByVal e As KeyEventArgs)
        If ((e.KeyCode = Keys.ControlKey) OrElse (e.KeyCode = Keys.ShiftKey)) Then
            Me.cntrlDown = False
        End If
    End Sub

    Private Sub CADPictBoxMouseWeel(ByVal sender As Object, ByVal e As MouseEventArgs)
        If (e.Delta < 0) Then
            Me.Zoom(0.7!)
        Else
            Me.Zoom(1.3!)
        End If
        Me.Shift()
        Me.SetPictureBoxPosition(Me.Position)
    End Sub

    Public Sub CADPictBoxScroll(ByVal sender As Object, ByVal e As ScrollEventArgsExt)
        Me.LeftImagePosition = -Me.cadPictBox.Position.X
        Me.TopImagePosition = -Me.cadPictBox.Position.Y
        Me.cadPictBox.Invalidate()
    End Sub

    Public Function ChancelMove(ByVal x As Integer, ByVal y As Integer) As Boolean
        Return (((Math.Abs(CInt((Me.cX - x))) < 2) AndAlso (Math.Abs(CInt((Me.cY - y))) < 2)) OrElse (Me.cadImage.SelectEntitiesCount = 0))
    End Function

    Public Sub ChangeControlState()
        Dim detNullImg As Boolean = (Not Me.cadImage Is Nothing)
        Me.EnableButton(detNullImg)
        Dim tmp As Boolean = False
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            tmp = True
        End If
        Me.miWhiteBack.Checked = tmp
        Me.miBlackBack.Checked = Not tmp
        If detNullImg Then
            Me.tlbTool.Buttons.Item(3).Pushed = tmp
            Me.tlbTool.Buttons.Item(4).Pushed = Not tmp
        Else
            Me.tlbTool.Buttons.Item(3).Pushed = False
            Me.tlbTool.Buttons.Item(4).Pushed = False
        End If
        tmp = Me.textVisible
        Me.miTextsShow.Checked = tmp
        tmp = Me.dimVisible
        Me.miDimShow.Checked = tmp
        Me.miEntitiesTree.Checked = Me.trvEntity.Visible
        tmp = Me.colorDraw
        Me.miColorDraw.Checked = tmp
        Me.miBlackDraw.Checked = Not tmp
        If (Not Me.cadImage Is Nothing) Then
            tmp = Me.cadImage.UseWinEllipse
        Else
            tmp = False
        End If
        Me.miArcsSplit.Checked = Not tmp
        Me.miShowLineWeight.Checked = Me.showLineWeight
        If (Me.curLngInd < Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngInd).Checked = False
        End If
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngInd) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngInd).Checked = True
        End If
        Me.tlbTool.Buttons.Item(&H1A).Pushed = Me.enableSnap
        Me.tlbTool.Buttons.Item(7).Pushed = Me.useSHXFonts
    End Sub

    Public Sub ChangeDimensionsVisiblity()
        Me.dimVisible = Not Me.dimVisible
        Me.cadImage.DimensionsVisible = Me.dimVisible
        Me.cadPictBox.Invalidate()
    End Sub

    Public Function ChangeEntityOnMouseMove(ByVal pt As Point) As Boolean
        If (Me.cadImage.SelectEntitiesCount <> 0) Then
            If Not Me.CreateNewEntity Then
                If (Not Me.cadImage.CurrentMarker Is Nothing) Then
                    Me.ChangeMarkerPosition(pt.X, pt.Y)
                    Return True
                End If
                Me.ChangeEntityPositionExt(pt.X, pt.Y)
            End If
            Return True
        End If
        Return False
    End Function

    Private Function ChangeEntityOnMouseUp(ByVal pt As Point) As Boolean
        If (Not Me.cadImage.CurrentMarker Is Nothing) Then
            If Not Me.ChancelMove(pt.X, pt.Y) Then
                Me.SetNewMarkerPosition()
                Return True
            End If
        ElseIf (Not Me.CreateNewEntity AndAlso Not Me.ChancelMove(pt.X, pt.Y)) Then
            Me.SetNewEntityPosition()
            Return True
        End If
        Return False
    End Function

    Private Sub ChangeEntityPositionExt(ByVal x As Integer, ByVal y As Integer)
        Dim gr As Graphics = Me.cadPictBox.CreateGraphics
        Me.cadImage.DrawMoveEntityTrace(-Me.startPt.X, -Me.StartPoint.Y, Me.cadPictBox)
        Me.cadImage.DrawMoveEntityTrace(-(Me.cX - x), -(Me.cY - y), Me.cadPictBox)
        Me.startPt.X = (Me.cX - x)
        Me.startPt.Y = (Me.cY - y)
    End Sub

    Public Sub ChangeLanguage(ByVal val As String, ByVal index As Integer)
        Me.curLngInd = index
        Me.lngFile = (val & ApplicationConstants.lngextstr)
        Me.SetAllFormsLanguageSettings()
        Me.SetLNG()
        Me.ChangeControlState()
    End Sub

    Private Sub ChangeMarkerPosition(ByVal x As Integer, ByVal y As Integer)
        Dim gr As Graphics = Me.cadPictBox.CreateGraphics
        If ((Me.startPt.X <> 0) OrElse (Me.StartPoint.Y <> 0)) Then
            Me.cadImage.DrawChangeEntity(Me.StartPoint.X, Me.StartPoint.Y, Me.cadPictBox)
        Else
            Me.endPt.X = x
            Me.endPt.Y = y
        End If
        Me.cadImage.DrawChangeEntity((Me.cX - x), (Me.cY - y), Me.cadPictBox)
        Me.startPt.X = (Me.cX - x)
        Me.startPt.Y = (Me.cY - y)
    End Sub

    Private Sub ChangeSelectionCond(ByVal val As Boolean)
        If val Then
            Me.cadImage.SelectionMode = SelectionEntityMode.Enabled
        Else
            Me.cadImage.SelectionMode = SelectionEntityMode.Disabled
        End If
        Me.cadImage.ClearSelectCollection()
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ChangeShowLineWeight()
        Me.showLineWeight = Not Me.showLineWeight
        Me.cadImage.IsShowLineWeight = Me.showLineWeight
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub ChangeTextsType(ByVal val As Boolean)
        Me.useSHXFonts = val
        CADConst.UseSHXFonts = Me.useSHXFonts
        CADConst.UseTTFFonts = Not Me.useSHXFonts
        CADConst.UseMultyTTFFonts = Not Me.useSHXFonts
        Me.ReOpen()
    End Sub

    Public Sub ChangeTextsVisiblity()
        Me.textVisible = Not Me.textVisible
        Me.cadImage.TextVisible = Me.textVisible
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ChangeTreeVisiblity(ByVal val As Boolean)
        If val Then
            CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImage)
        End If
        Me.spltPictBox.Visible = val
        Me.trvPanel.Visible = val
        Me.DoResize()
    End Sub

    Public Sub chLay_ItemCheck(ByVal sender As Object, ByVal e As ItemCheckEventArgs)
        If (e.NewValue = CheckState.Checked) Then
            Me.cadImage.SetLayerVisible(e.Index, True, Me.lForm.detInvalidate)
        ElseIf (e.NewValue = CheckState.Unchecked) Then
            Me.cadImage.SetLayerVisible(e.Index, False, Me.lForm.detInvalidate)
        End If
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ClearCADImage()
        Me.lForm.LayerList.Clear()
        RemoveHandler Me.lForm.LayerList.SelectItemEvent, Me.listItemSelectDel
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.Dispose()
            Me.cadImage = Nothing
        End If
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.Position = New PointF
    End Sub

    Public Sub ClearSelection()
        Me.entCreator.Disable()
        Me.stopSnap = True
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.ClearSelection()
            Me.cadImage.ClearMarkers()
            Me.propGrid.SelectedObject = Nothing
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Public Sub CloseFile()
        Me.cadImage.Dispose()
        Me.cadImage = Nothing
        Me.entCreator.Image = Nothing
        Me.EnableButton(False)
        Me.propGrid.SelectedObject = Nothing
        Me.trvEntity.Nodes.Clear()
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub CreateNewImage()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.Dispose()
        End If
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.Position = New PointF
        Me.cadImage = New CADImage
        Me.cadImage.SelectionMode = SelectionEntityMode.Enabled
        Me.cadImage.UseDoubleBuffering = False
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            Me.White_Click()
        Else
            Me.Black_Click()
        End If
        Me.cadImage.InitialNewImage()
        Me.EnableButton(True)
        Me.trvEntity.Nodes.Clear()
        Me.DoResize()
        ObjEntity.cadImage = Me.cadImage
        ObjEntity.propGrid = Me.propGrid
        Me.cadImage.UseWinEllipse = False
        Me.entCreator.Image = Me.cadImage
        Me.prtForm.Image = Me.cadImage
        Me.SetLayList()
    End Sub

    Public Sub CreateNewSettingsList()
        Dim tmp As String
        Me.settingsLst = New SortedList
        Me.settingsLst.Add(ApplicationConstants.languagepath, Me.mlng.Path)
        Me.settingsLst.Add(ApplicationConstants.languagestr, Me.lngFile)
        Me.settingsLst.Add(ApplicationConstants.languageIDstr, Me.curLngInd)
        If (Me.cadPictBox.BackColor.Equals(Color.Black)) Then
            tmp = ApplicationConstants.blackstr2
        Else
            tmp = ApplicationConstants.whitestr
        End If
        Me.settingsLst.Add(ApplicationConstants.backcolorstr, tmp)
        Me.settingsLst.Add(ApplicationConstants.showentitystr, Me.trvPanel.Visible)
        Me.settingsLst.Add(ApplicationConstants.colordrawstr, Me.colorDraw)
        Dim cn As Integer = Me.shxFrm.lstDir.Items.Count
        Me.settingsLst.Add(ApplicationConstants.shxpathcnstr, Me.shxFrm.lstDir.Items.Count)
        Dim i As Integer
        For i = 0 To cn - 1
            Me.settingsLst.Add(String.Format("SHXPath_{0}", (i + 1)), Me.shxFrm.lstDir.Items.Item(i))
        Next i
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.settingsLst.Add("Type_license", "floating")
            Me.settingsLst.Add("Host", Me.floatLicFrm.Host)
            Me.settingsLst.Add("Port", Me.floatLicFrm.Port)
            Me.settingsLst.Add("Application", Me.floatLicFrm.App)
        Else
            Me.settingsLst.Add("Type license", "register")
        End If
    End Sub

    Public Function Deserialize(ByVal fileName As String) As Object
        Dim stm As Stream = File.Open(fileName, FileMode.Open, FileAccess.Read)
        Dim res As Object = New BinaryFormatter().Deserialize(stm)
        stm.Close()
        Return res
    End Function

    Private Sub DisableEntityCreator()
        If (Me.entCreator.Enabled AndAlso (((Me.entCreator.Type = CreatorType.Pen) OrElse ((Me.entCreator.Type = CreatorType.Polyline) AndAlso Me.entCreator.EndPoly)) OrElse (Me.entCreator.Type = CreatorType.Point))) Then
            Me.entCreator.Disable()
        End If
    End Sub

    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

    Public Sub DoBlackColor()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.DrawMode = CADDrawMode.Black
            Me.colorDraw = False
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Private Sub DoExtentsForPrint()
        Me.cadImage.ClearSelection()
        Me.cadImage.ClearMarkers()
        Me.cadImage.GetExtents()
    End Sub

    Public Sub DoNormalColor()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.DrawMode = CADDrawMode.Normal
            Me.colorDraw = True
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Public Sub DoResize()
        If (Not Me.cadImage Is Nothing) Then
            Dim wh As Single = CSng((Me.cadImage.AbsWidth / Me.cadImage.AbsHeight))
            Dim new_wh As Single = (CSng(Me.cadPictBox.ClientRectangle.Width) / CSng(Me.cadPictBox.ClientRectangle.Height))
            If TypeOf Me.cadImage Is CADRasterImage Then
                Me.visibleArea = New SizeF(CSng(Me.cadImage.AbsWidth), CSng(Me.cadImage.AbsHeight))
            Else
                Me.visibleArea = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
            End If
            If (new_wh > wh) Then
                Me.visibleArea.Width = (Me.visibleArea.Height * wh)
            ElseIf (new_wh < wh) Then
                Me.visibleArea.Height = (Me.visibleArea.Width / wh)
            Else
                Me.visibleArea = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
            End If
            Me.LeftImagePosition = ((Me.cadPictBox.ClientRectangle.Width - Me.visibleArea.Width) / 2.0!)
            Me.TopImagePosition = ((Me.cadPictBox.ClientRectangle.Height - Me.visibleArea.Height) / 2.0!)
            Me.cadPictBox.Invalidate()
        End If
    End Sub

    Public Sub DoZoomIn()
        If (Not Me.cadImage Is Nothing) Then
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = (Me.ImageScale * 2.0!)
            Me.cadPictBox.Invalidate()
            Me.SetPictureBoxPosition(Me.Position)
            Me.stopSnap = False
        End If
    End Sub

    Public Sub DoZoomOut()
        If (Not Me.cadImage Is Nothing) Then
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = (Me.ImageScale / 2.0!)
            Me.cadPictBox.Invalidate()
            Me.SetPictureBoxPosition(Me.Position)
            Me.stopSnap = False
        End If
    End Sub

    Public Sub DrawCADImage(ByVal gr As Graphics)
        If (Not Me.cadImage Is Nothing) Then
            Me.Shift()
            Dim tmp As RectangleF = Me.ImageRectangleF
            Me.SetSizePictureBox(New Size(CInt(tmp.Width), CInt(tmp.Height)))
            Me.cadImage.Draw(gr, tmp)
        End If
    End Sub

    Public Sub EnableButton(ByVal aVal As Boolean)
        Dim i As Integer
        For i = 1 To 8 - 1
            Me.tlbTool.Buttons.Item(i).Enabled = aVal
        Next i
        For i = &H17 To &H1A - 1
            Me.tlbTool.Buttons.Item(i).Enabled = aVal
        Next i
        Me.miSaveAsDXF.Enabled = aVal
        Me.miScale.Enabled = aVal
        Me.miSaveFile.Enabled = aVal
        Me.miCopyAsBMP.Enabled = aVal
        Me.miZoomIn.Enabled = aVal
        Me.miZoomOut.Enabled = aVal
        Me.miFit.Enabled = aVal
        Me.miColorDraw.Enabled = aVal
        Me.miBlackDraw.Enabled = aVal
        Me.miWhiteBack.Enabled = aVal
        Me.miBlackBack.Enabled = aVal
        Me.miShowLineWeight.Enabled = aVal
        Me.miArcsSplit.Enabled = aVal
        Me.miDimShow.Enabled = aVal
        Me.miTextsShow.Enabled = aVal
        Me.miLayersShow.Enabled = aVal
        Me.miClose.Enabled = aVal
        Me.miPrint.Enabled = aVal
        Me.miPrintCustom.Enabled = aVal
        Me.miPrintPreview.Enabled = aVal
        Me.miUndo.Enabled = aVal
        Me.miRedo.Enabled = aVal
        Me.miDelete.Enabled = aVal
        Me.miCopy.Enabled = aVal
        Me.miPaste.Enabled = aVal
        Me.miCut.Enabled = aVal
        Me.miSerializeEntities.Enabled = aVal
    End Sub

    Private Function EnableNewEntityCreator() As Boolean
        Dim seltp As CreatorType = CreatorType.Undetected
        Select Case Me.addEntity
            Case 0
                seltp = CreatorType.Image
                Exit Select
            Case 1
                seltp = CreatorType.Solid
                Exit Select
            Case 2
                seltp = CreatorType.Line
                Exit Select
            Case 3
                seltp = CreatorType.Rectangle
                Exit Select
            Case 4
                seltp = CreatorType.Ellipse
                Exit Select
            Case 5
                seltp = CreatorType.Text
                Exit Select
            Case 6
                seltp = CreatorType.Polyline
                Exit Select
            Case 7
                seltp = CreatorType.Pen
                Exit Select
            Case 8
                seltp = CreatorType.Hatch
                Exit Select
            Case 9
                seltp = CreatorType.Cloud
                Exit Select
            Case 10
                seltp = CreatorType.MText
                Exit Select
            Case 11
                seltp = CreatorType.Point
                Exit Select
        End Select
        If (seltp <> CreatorType.Undetected) Then
            Me.entCreator.EnableCreator(seltp)
            Me.curAddEntityType = seltp
            Return True
        End If
        Return False
    End Function

    Public Sub EndAddEntity(ByVal val As Boolean)
        If (Me.curAddEntityType <> CreatorType.Undetected) Then
            Me.SetAddEntityMode(Me.curAddEntityType)
            Me.SetEnableChecked()
            Me.ChangeControlState()
        End If
        Me.detMouseDown = val
    End Sub

    Private Sub GetExtents()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.GetExtents()
            Me.DoResize()
        End If
    End Sub

    Public Function GetRealPoint(ByVal x As Integer, ByVal y As Integer) As DPoint
        Dim tmpRect As RectangleF = Me.ImageRectangleF
        Return CADConst.GetRealPoint(x, y, Me.cadImage, tmpRect)
    End Function

    Private Sub InitialCADImportForms()
        Me.lForm = New LayerForm
        Me.aboutForm = New AboutForm
        Me.prtForm = New CADImport.Printing.PrintingForm
        Me.prtForm.LayerForm = Me.lForm
        Me.shxFrm = New SHXForm
        Me.rasterSizeForm = New SetRasterSizeForm
        Me.floatLicFrm = New FloatLicForm
        AddHandler Me.floatLicFrm.Change, New System.EventHandler(AddressOf Me.InvalidateImage)
        Me.regFrm = New RegForm
    End Sub

#Region " Windows Form Designer generated code "
    Private Sub InitializeComponent()
        Me.components = New Container
        Dim resources As New ResourceManager(GetType(MainForm))
        Me.stBar = New StatusBar
        Me.sbOpen = New StatusBarPanel
        Me.sbScale = New StatusBarPanel
        Me.sbCoord = New StatusBarPanel
        Me.tlbTool = New ToolBar
        Me.tlbOpen = New ToolBarButton
        Me.tlbZoomIn = New ToolBarButton
        Me.tlbZoomOut = New ToolBarButton
        Me.tlbWhite = New ToolBarButton
        Me.tlbBlack = New ToolBarButton
        Me.tlbLay = New ToolBarButton
        Me.tlbSave = New ToolBarButton
        Me.tlbShx = New ToolBarButton
        Me.tlbAddImgEnt = New ToolBarButton
        Me.tlbAddSolid = New ToolBarButton
        Me.tlbLine = New ToolBarButton
        Me.tlbRect = New ToolBarButton
        Me.tlbCircle = New ToolBarButton
        Me.tlbText = New ToolBarButton
        Me.tlbPoly = New ToolBarButton
        Me.tlbPen = New ToolBarButton
        Me.tlbAddHatch = New ToolBarButton
        Me.tlbCloud = New ToolBarButton
        Me.tlbAddMText = New ToolBarButton
        Me.tlbPoint = New ToolBarButton
        Me.tlbOptions = New ToolBarButton
        Me.tlbNew = New ToolBarButton
        Me.tlbGetExt = New ToolBarButton
        Me.tlbDel = New ToolBarButton
        Me.tlbUndo = New ToolBarButton
        Me.tlbRedo = New ToolBarButton
        Me.tlbSnap = New ToolBarButton
        Me.toolBtnImageList = New ImageList(Me.components)
        Me.cadPictBox = New CADPictureBox
        Me.saveImgDlg = New SaveFileDialog
        Me.mainMenu = New MainMenu
        Me.miFile = New MenuItem
        Me.miOpenFile = New MenuItem
        Me.miSaveFile = New MenuItem
        Me.miSaveAsDXF = New MenuItem
        Me.miSerializeEntities = New MenuItem
        Me.miDeserializeEntities = New MenuItem
        Me.miPrint = New MenuItem
        Me.miPrintCustom = New MenuItem
        Me.miPrintPreview = New MenuItem
        Me.miClose = New MenuItem
        Me.miSep1 = New MenuItem
        Me.miExit = New MenuItem
        Me.miEdit = New MenuItem
        Me.miCopyAsBMP = New MenuItem
        Me.miUndo = New MenuItem
        Me.miRedo = New MenuItem
        Me.miDelete = New MenuItem
        Me.miCopy = New MenuItem
        Me.miCut = New MenuItem
        Me.miPaste = New MenuItem
        Me.miView = New MenuItem
        Me.miEntitiesTree = New MenuItem
        Me.miSep2 = New MenuItem
        Me.miZoomIn = New MenuItem
        Me.miZoomOut = New MenuItem
        Me.miScale = New MenuItem
        Me.miZoom10 = New MenuItem
        Me.miZoom25 = New MenuItem
        Me.miZoom50 = New MenuItem
        Me.miZoom100 = New MenuItem
        Me.miZoom200 = New MenuItem
        Me.miZoom400 = New MenuItem
        Me.miZoom800 = New MenuItem
        Me.miFit = New MenuItem
        Me.miSep3 = New MenuItem
        Me.miSHXFontsPaths = New MenuItem
        Me.miOptions = New MenuItem
        Me.miCADFiles = New MenuItem
        Me.miColorDraw = New MenuItem
        Me.miBlackDraw = New MenuItem
        Me.miWhiteBack = New MenuItem
        Me.miBlackBack = New MenuItem
        Me.miSep4 = New MenuItem
        Me.miShowLineWeight = New MenuItem
        Me.miArcsSplit = New MenuItem
        Me.miDimShow = New MenuItem
        Me.miTextsShow = New MenuItem
        Me.miSep5 = New MenuItem
        Me.miLayersShow = New MenuItem
        Me.miReg = New MenuItem
        Me.miLng = New MenuItem
        Me.miRegister = New MenuItem
        Me.miFloatLic = New MenuItem
        Me.miAbout = New MenuItem
        Me.saveDXFDlg = New SaveFileDialog
        Me.trvPanel = New Panel
        Me.trvEntity = New TreeView
        Me.spProp = New Splitter
        Me.propGrid = New PropertyGrid
        Me.spltPictBox = New Splitter
        Me.printPrevDlg = New PrintPreviewDialog
        Me.setColorDlg = New ColorDialog
        Me.openFileDlg = New OpenFileDialog
        Me.dlgSaveSerializeFile = New SaveFileDialog
        Me.dlgOpenSerializeFile = New OpenFileDialog
        Me.sbOpen.BeginInit()
        Me.sbScale.BeginInit()
        Me.sbCoord.BeginInit()
        Me.trvPanel.SuspendLayout()
        MyBase.SuspendLayout()
        Me.stBar.Font = New Font("Microsoft Sans Serif", 8.0!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.stBar.Location = New Point(&HD0, &H17E)
        Me.stBar.Name = "stBar"
        Me.stBar.Panels.AddRange(New StatusBarPanel() {Me.sbOpen, Me.sbScale, Me.sbCoord})
        Me.stBar.ShowPanels = True
        Me.stBar.Size = New Size(&H1A0, &H10)
        Me.stBar.TabIndex = 9
        Me.sbOpen.AutoSize = StatusBarPanelAutoSize.Contents
        Me.sbOpen.MinWidth = 100
        Me.sbOpen.ToolTipText = "File Name"
        Me.sbScale.AutoSize = StatusBarPanelAutoSize.Contents
        Me.sbScale.Text = "100%"
        Me.sbScale.ToolTipText = "Scale"
        Me.sbScale.Width = &H2A
        Me.sbCoord.Alignment = HorizontalAlignment.Right
        Me.sbCoord.AutoSize = StatusBarPanelAutoSize.Contents
        Me.sbCoord.Text = "0 - 0 - 0"
        Me.sbCoord.Width = &H33
        Me.tlbTool.Appearance = ToolBarAppearance.Flat
        Me.tlbTool.BorderStyle = BorderStyle.FixedSingle
        Me.tlbTool.Buttons.AddRange(New ToolBarButton() {Me.tlbOpen, Me.tlbZoomIn, Me.tlbZoomOut, Me.tlbWhite, Me.tlbBlack, Me.tlbLay, Me.tlbSave, Me.tlbShx, Me.tlbAddImgEnt, Me.tlbAddSolid, Me.tlbLine, Me.tlbRect, Me.tlbCircle, Me.tlbText, Me.tlbPoly, Me.tlbPen, Me.tlbAddHatch, Me.tlbCloud, Me.tlbAddMText, Me.tlbPoint, Me.tlbOptions, Me.tlbNew, Me.tlbGetExt, Me.tlbDel, Me.tlbUndo, Me.tlbRedo, Me.tlbSnap})
        Me.tlbTool.ButtonSize = New Size(20, 20)
        Me.tlbTool.DropDownArrows = True
        Me.tlbTool.ImageList = Me.toolBtnImageList
        Me.tlbTool.Location = New Point(0, 0)
        Me.tlbTool.Name = "tlbTool"
        Me.tlbTool.ShowToolTips = True
        Me.tlbTool.Size = New Size(&H270, &H1D)
        Me.tlbTool.TabIndex = 10
        AddHandler Me.tlbTool.ButtonClick, New ToolBarButtonClickEventHandler(AddressOf Me.tlbTool_ButtonClick)
        AddHandler Me.tlbTool.KeyDown, New KeyEventHandler(AddressOf Me.CADPictBoxKeyDown)
        Me.tlbOpen.ImageIndex = 1
        Me.tlbOpen.ToolTipText = "Open Picture"
        Me.tlbZoomIn.Enabled = False
        Me.tlbZoomIn.ImageIndex = 2
        Me.tlbZoomIn.ToolTipText = "Zoom In (+)"
        Me.tlbZoomOut.Enabled = False
        Me.tlbZoomOut.ImageIndex = 3
        Me.tlbZoomOut.ToolTipText = "Zoom Out (-)"
        Me.tlbWhite.Enabled = False
        Me.tlbWhite.ImageIndex = 4
        Me.tlbWhite.ToolTipText = "White Background"
        Me.tlbBlack.Enabled = False
        Me.tlbBlack.ImageIndex = 5
        Me.tlbBlack.ToolTipText = "Black Background"
        Me.tlbLay.Enabled = False
        Me.tlbLay.ImageIndex = 6
        Me.tlbLay.ToolTipText = "Show Layers"
        Me.tlbSave.Enabled = False
        Me.tlbSave.ImageIndex = 7
        Me.tlbSave.ToolTipText = "Save Picture..."
        Me.tlbShx.Enabled = False
        Me.tlbShx.ImageIndex = 8
        Me.tlbShx.Pushed = True
        Me.tlbShx.ToolTipText = "Use SHX fonts"
        Me.tlbAddImgEnt.ImageIndex = 12
        Me.tlbAddImgEnt.ToolTipText = "Add new ImageEnt"
        Me.tlbAddSolid.ImageIndex = 10
        Me.tlbAddSolid.ToolTipText = "Add new solid"
        Me.tlbLine.ImageIndex = 13
        Me.tlbLine.ToolTipText = "Add new line"
        Me.tlbRect.ImageIndex = 14
        Me.tlbRect.ToolTipText = "Add new rect"
        Me.tlbCircle.ImageIndex = 15
        Me.tlbCircle.ToolTipText = "Add new ellipse"
        Me.tlbText.ImageIndex = &H10
        Me.tlbText.ToolTipText = "Add new text"
        Me.tlbPoly.ImageIndex = &H11
        Me.tlbPoly.ToolTipText = "Add new poly"
        Me.tlbPen.ImageIndex = &H12
        Me.tlbPen.ToolTipText = "Add new pen"
        Me.tlbAddHatch.ImageIndex = &H1A
        Me.tlbCloud.ImageIndex = &H19
        Me.tlbAddMText.ImageIndex = &H10
        Me.tlbAddMText.ToolTipText = "Add MText"
        Me.tlbPoint.ImageIndex = &H15
        Me.tlbOptions.ImageIndex = 9
        Me.tlbOptions.ToolTipText = "Options"
        Me.tlbNew.ImageIndex = 11
        Me.tlbNew.ToolTipText = "New Picture"
        Me.tlbGetExt.ImageIndex = 20
        Me.tlbGetExt.ToolTipText = "Fit drawing to window"
        Me.tlbDel.Enabled = False
        Me.tlbDel.ImageIndex = &H18
        Me.tlbUndo.Enabled = False
        Me.tlbUndo.ImageIndex = &H17
        Me.tlbUndo.ToolTipText = "Undo"
        Me.tlbRedo.Enabled = False
        Me.tlbRedo.ImageIndex = &H16
        Me.tlbSnap.ImageIndex = &H1B
        Me.tlbSnap.Pushed = True
        Me.toolBtnImageList.ColorDepth = ColorDepth.Depth24Bit
        Me.toolBtnImageList.ImageSize = New Size(&H10, &H10)
        Me.toolBtnImageList.ImageStream = DirectCast(resources.GetObject("toolBtnImageList.ImageStream"), ImageListStreamer)
        Me.toolBtnImageList.TransparentColor = Color.Fuchsia
        Me.cadPictBox.BackColor = Color.Black
        Me.cadPictBox.BorderStyle = BorderStyle.FixedSingle
        Me.cadPictBox.Cursor = Cursors.Default
        Me.cadPictBox.Dock = DockStyle.Fill
        Me.cadPictBox.DoubleBuffering = True
        Me.cadPictBox.Location = New Point(&HD0, &H1D)
        Me.cadPictBox.Name = "cadPictBox"
        Me.cadPictBox.Position = New Point(0, 0)
        Me.cadPictBox.Size = New Size(&H1A0, &H161)
        Me.cadPictBox.TabIndex = 13
        Me.cadPictBox.TabStop = False
        Me.cadPictBox.VirtualSize = New Size(0, 0)
        AddHandler Me.cadPictBox.MouseUp, New MouseEventHandler(AddressOf Me.cadPictBox_MouseUp)
        AddHandler Me.cadPictBox.Paint, New PaintEventHandler(AddressOf Me.cadPictBox_Paint)
        AddHandler Me.cadPictBox.MouseMove, New MouseEventHandler(AddressOf Me.cadPictBox_MouseMove)
        AddHandler Me.cadPictBox.MouseDown, New MouseEventHandler(AddressOf Me.cadPictBox_MouseDown)
        Me.saveImgDlg.Filter = "*.bmp|*.bmp|*.jpg|*.jpg|*.tiff|*.tiff|*.gif|*.gif|*.emf|*.emf|*.dxf|*.dxf"
        Me.saveImgDlg.RestoreDirectory = True
        Me.mainMenu.MenuItems.AddRange(New MenuItem() {Me.miFile, Me.miEdit, Me.miView, Me.miCADFiles, Me.miReg})
        Me.miFile.Index = 0
        Me.miFile.MenuItems.AddRange(New MenuItem() {Me.miOpenFile, Me.miSaveFile, Me.miSaveAsDXF, Me.miSerializeEntities, Me.miDeserializeEntities, Me.miPrint, Me.miPrintCustom, Me.miPrintPreview, Me.miClose, Me.miSep1, Me.miExit})
        Me.miFile.Text = "&File"
        Me.miOpenFile.Index = 0
        Me.miOpenFile.Text = "Open Picture..."
        AddHandler Me.miOpenFile.Click, New System.EventHandler(AddressOf Me.miOpenFile_Click)
        Me.miSaveFile.Enabled = False
        Me.miSaveFile.Index = 1
        Me.miSaveFile.Text = "Save Picture..."
        AddHandler Me.miSaveFile.Click, New System.EventHandler(AddressOf Me.miSaveFile_Click)
        Me.miSaveAsDXF.Enabled = False
        Me.miSaveAsDXF.Index = 2
        Me.miSaveAsDXF.Text = "Save as DXF..."
        AddHandler Me.miSaveAsDXF.Click, New System.EventHandler(AddressOf Me.miSaveAsDXF_Click)
        Me.miSerializeEntities.Enabled = False
        Me.miSerializeEntities.Index = 3
        Me.miSerializeEntities.Text = "Serialize entities..."
        AddHandler Me.miSerializeEntities.Click, New System.EventHandler(AddressOf Me.miSerializeEntities_Click)
        Me.miDeserializeEntities.Index = 4
        Me.miDeserializeEntities.Text = "Deserialize entities..."
        AddHandler Me.miDeserializeEntities.Click, New System.EventHandler(AddressOf Me.miDeserializeEntities_Click)
        Me.miPrint.Enabled = False
        Me.miPrint.Index = 5
        Me.miPrint.Text = "Print "
        AddHandler Me.miPrint.Click, New System.EventHandler(AddressOf Me.miPrint_Click)
        Me.miPrintCustom.Enabled = False
        Me.miPrintCustom.Index = 6
        Me.miPrintCustom.Text = "Custom Print Preview..."
        AddHandler Me.miPrintCustom.Click, New System.EventHandler(AddressOf Me.miPrintCustom_Click)
        Me.miPrintPreview.Enabled = False
        Me.miPrintPreview.Index = 7
        Me.miPrintPreview.Text = "Print Preview..."
        AddHandler Me.miPrintPreview.Click, New System.EventHandler(AddressOf Me.miPrintPreview_Click)
        Me.miClose.Enabled = False
        Me.miClose.Index = 8
        Me.miClose.Text = "Close Picture"
        AddHandler Me.miClose.Click, New System.EventHandler(AddressOf Me.miClose_Click)
        Me.miSep1.Index = 9
        Me.miSep1.Text = "-"
        Me.miExit.Index = 10
        Me.miExit.Text = "Close"
        AddHandler Me.miExit.Click, New System.EventHandler(AddressOf Me.miExit_Click)
        Me.miEdit.Index = 1
        Me.miEdit.MenuItems.AddRange(New MenuItem() {Me.miCopyAsBMP, Me.miUndo, Me.miRedo, Me.miDelete, Me.miCopy, Me.miCut, Me.miPaste})
        Me.miEdit.Text = "&Edit"
        Me.miCopyAsBMP.Enabled = False
        Me.miCopyAsBMP.Index = 0
        Me.miCopyAsBMP.Text = "Copy as BMP"
        AddHandler Me.miCopyAsBMP.Click, New System.EventHandler(AddressOf Me.miCopyAsBMP_Click)
        Me.miUndo.Enabled = False
        Me.miUndo.Index = 1
        Me.miUndo.Shortcut = Shortcut.CtrlZ
        Me.miUndo.Text = "Undo"
        AddHandler Me.miUndo.Click, New System.EventHandler(AddressOf Me.miUndo_Click)
        Me.miRedo.Enabled = False
        Me.miRedo.Index = 2
        Me.miRedo.Shortcut = Shortcut.CtrlY
        Me.miRedo.Text = "Redo"
        AddHandler Me.miRedo.Click, New System.EventHandler(AddressOf Me.miRedo_Click)
        Me.miDelete.Enabled = False
        Me.miDelete.Index = 3
        Me.miDelete.Shortcut = Shortcut.Del
        Me.miDelete.Text = "Delete"
        AddHandler Me.miDelete.Click, New System.EventHandler(AddressOf Me.miDelete_Click)
        Me.miCopy.Enabled = False
        Me.miCopy.Index = 4
        Me.miCopy.Shortcut = Shortcut.CtrlC
        Me.miCopy.Text = "&Copy"
        AddHandler Me.miCopy.Click, New System.EventHandler(AddressOf Me.miCopy_Click)
        Me.miCut.Enabled = False
        Me.miCut.Index = 5
        Me.miCut.Shortcut = Shortcut.CtrlX
        Me.miCut.Text = "Cu&t"
        AddHandler Me.miCut.Click, New System.EventHandler(AddressOf Me.miCut_Click)
        Me.miPaste.Enabled = False
        Me.miPaste.Index = 6
        Me.miPaste.Shortcut = Shortcut.CtrlV
        Me.miPaste.Text = "Paste"
        AddHandler Me.miPaste.Click, New System.EventHandler(AddressOf Me.miPaste_Click)
        Me.miView.Index = 2
        Me.miView.MenuItems.AddRange(New MenuItem() {Me.miEntitiesTree, Me.miSep2, Me.miZoomIn, Me.miZoomOut, Me.miScale, Me.miFit, Me.miSep3, Me.miSHXFontsPaths, Me.miOptions})
        Me.miView.Text = "&View"
        Me.miEntitiesTree.Checked = True
        Me.miEntitiesTree.Index = 0
        Me.miEntitiesTree.Text = "Show entities panel"
        AddHandler Me.miEntitiesTree.Click, New System.EventHandler(AddressOf Me.miEntitiesTree_Click)
        Me.miSep2.Index = 1
        Me.miSep2.Text = "-"
        Me.miZoomIn.Enabled = False
        Me.miZoomIn.Index = 2
        Me.miZoomIn.Text = "Zoom In (+)"
        AddHandler Me.miZoomIn.Click, New System.EventHandler(AddressOf Me.miZoomIn_Click)
        Me.miZoomOut.Enabled = False
        Me.miZoomOut.Index = 3
        Me.miZoomOut.Text = "Zoom Out (-)"
        AddHandler Me.miZoomOut.Click, New System.EventHandler(AddressOf Me.miZoomOut_Click)
        Me.miScale.Enabled = False
        Me.miScale.Index = 4
        Me.miScale.MenuItems.AddRange(New MenuItem() {Me.miZoom10, Me.miZoom25, Me.miZoom50, Me.miZoom100, Me.miZoom200, Me.miZoom400, Me.miZoom800})
        Me.miScale.Text = "Scale"
        Me.miZoom10.Index = 0
        Me.miZoom10.Text = "10%"
        AddHandler Me.miZoom10.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom25.Index = 1
        Me.miZoom25.Text = "25%"
        AddHandler Me.miZoom25.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom50.Index = 2
        Me.miZoom50.Text = "50%"
        AddHandler Me.miZoom50.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom100.Index = 3
        Me.miZoom100.Text = "100%"
        AddHandler Me.miZoom100.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom200.Index = 4
        Me.miZoom200.Text = "200%"
        AddHandler Me.miZoom200.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom400.Index = 5
        Me.miZoom400.Text = "400%"
        AddHandler Me.miZoom400.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miZoom800.Index = 6
        Me.miZoom800.Text = "800%"
        AddHandler Me.miZoom800.Click, New System.EventHandler(AddressOf Me.miZoom_Click)
        Me.miFit.Enabled = False
        Me.miFit.Index = 5
        Me.miFit.Text = "Fit drawing to window"
        AddHandler Me.miFit.Click, New System.EventHandler(AddressOf Me.miFit_Click)
        Me.miSep3.Index = 6
        Me.miSep3.Text = "-"
        Me.miSHXFontsPaths.Index = 7
        Me.miSHXFontsPaths.Text = "SHX Fonts"
        AddHandler Me.miSHXFontsPaths.Click, New System.EventHandler(AddressOf Me.miSHXFontsPaths_Click)
        Me.miOptions.Index = 8
        Me.miOptions.Text = "Options"
        AddHandler Me.miOptions.Click, New System.EventHandler(AddressOf Me.miOptions_Click)
        Me.miCADFiles.Index = 3
        Me.miCADFiles.MenuItems.AddRange(New MenuItem() {Me.miColorDraw, Me.miBlackDraw, Me.miWhiteBack, Me.miBlackBack, Me.miSep4, Me.miShowLineWeight, Me.miArcsSplit, Me.miDimShow, Me.miTextsShow, Me.miSep5, Me.miLayersShow})
        Me.miCADFiles.Text = "&CAD files"
        Me.miColorDraw.Checked = True
        Me.miColorDraw.Enabled = False
        Me.miColorDraw.Index = 0
        Me.miColorDraw.RadioCheck = True
        Me.miColorDraw.Text = "Color drawing"
        AddHandler Me.miColorDraw.Click, New System.EventHandler(AddressOf Me.miColorDraw_Click)
        Me.miBlackDraw.Enabled = False
        Me.miBlackDraw.Index = 1
        Me.miBlackDraw.RadioCheck = True
        Me.miBlackDraw.Text = "Black drawing"
        AddHandler Me.miBlackDraw.Click, New System.EventHandler(AddressOf Me.miBlackDraw_Click)
        Me.miWhiteBack.Enabled = False
        Me.miWhiteBack.Index = 2
        Me.miWhiteBack.RadioCheck = True
        Me.miWhiteBack.Text = "White Background"
        AddHandler Me.miWhiteBack.Click, New System.EventHandler(AddressOf Me.miWhiteBack_Click)
        Me.miBlackBack.Enabled = False
        Me.miBlackBack.Index = 3
        Me.miBlackBack.RadioCheck = True
        Me.miBlackBack.Text = "Black Background"
        AddHandler Me.miBlackBack.Click, New System.EventHandler(AddressOf Me.miBlackBack_Click)
        Me.miSep4.Enabled = False
        Me.miSep4.Index = 4
        Me.miSep4.Text = "-"
        Me.miShowLineWeight.Checked = True
        Me.miShowLineWeight.Enabled = False
        Me.miShowLineWeight.Index = 5
        Me.miShowLineWeight.Text = "Show Lineweight"
        AddHandler Me.miShowLineWeight.Click, New System.EventHandler(AddressOf Me.miShowLineWeight_Click)
        Me.miArcsSplit.Checked = True
        Me.miArcsSplit.Enabled = False
        Me.miArcsSplit.Index = 6
        Me.miArcsSplit.Text = "Arcs Splitted"
        AddHandler Me.miArcsSplit.Click, New System.EventHandler(AddressOf Me.miArcsSplit_Click)
        Me.miDimShow.Checked = True
        Me.miDimShow.Enabled = False
        Me.miDimShow.Index = 7
        Me.miDimShow.Text = "Dimensions Show"
        AddHandler Me.miDimShow.Click, New System.EventHandler(AddressOf Me.miDimShow_Click)
        Me.miTextsShow.Checked = True
        Me.miTextsShow.Enabled = False
        Me.miTextsShow.Index = 8
        Me.miTextsShow.Text = "Texts Show"
        AddHandler Me.miTextsShow.Click, New System.EventHandler(AddressOf Me.miTextsShow_Click)
        Me.miSep5.Enabled = False
        Me.miSep5.Index = 9
        Me.miSep5.Text = "-"
        Me.miLayersShow.Enabled = False
        Me.miLayersShow.Index = 10
        Me.miLayersShow.Text = "Show Layers"
        AddHandler Me.miLayersShow.Click, New System.EventHandler(AddressOf Me.miLayersShow_Click)
        Me.miReg.Index = 4
        Me.miReg.MenuItems.AddRange(New MenuItem() {Me.miLng, Me.miRegister, Me.miFloatLic, Me.miAbout})
        Me.miReg.Text = "?"
        Me.miLng.Index = 0
        Me.miLng.Text = "Language"
        Me.miRegister.Index = 1
        Me.miRegister.Text = "Register "
        AddHandler Me.miRegister.Click, New System.EventHandler(AddressOf Me.miRegister_Click)
        Me.miFloatLic.Index = 2
        Me.miFloatLic.Text = "Floating License Registration..."
        AddHandler Me.miFloatLic.Click, New System.EventHandler(AddressOf Me.miFloatLic_Click)
        Me.miAbout.Index = 3
        Me.miAbout.Text = "About..."
        AddHandler Me.miAbout.Click, New System.EventHandler(AddressOf Me.miAbout_Click)
        Me.saveDXFDlg.DefaultExt = "*.dxf"
        Me.saveDXFDlg.Filter = "*.dxf|*.dxf"
        Me.trvPanel.Controls.Add(Me.trvEntity)
        Me.trvPanel.Controls.Add(Me.spProp)
        Me.trvPanel.Controls.Add(Me.propGrid)
        Me.trvPanel.Dock = DockStyle.Left
        Me.trvPanel.Location = New Point(0, &H1D)
        Me.trvPanel.Name = "trvPanel"
        Me.trvPanel.Size = New Size(&HD0, &H171)
        Me.trvPanel.TabIndex = 14
        Me.trvEntity.BackColor = Color.Black
        Me.trvEntity.BorderStyle = BorderStyle.None
        Me.trvEntity.CheckBoxes = True
        Me.trvEntity.Dock = DockStyle.Fill
        Me.trvEntity.ForeColor = Color.White
        Me.trvEntity.ImageIndex = -1
        Me.trvEntity.Indent = &H13
        Me.trvEntity.ItemHeight = &H10
        Me.trvEntity.Location = New Point(0, 0)
        Me.trvEntity.Name = "trvEntity"
        Me.trvEntity.SelectedImageIndex = -1
        Me.trvEntity.Size = New Size(&HD0, &H76)
        Me.trvEntity.TabIndex = &H10
        AddHandler Me.trvEntity.AfterCheck, New TreeViewEventHandler(AddressOf Me.trvEntity_AfterCheck)
        AddHandler Me.trvEntity.AfterSelect, New TreeViewEventHandler(AddressOf Me.trvEntity_AfterSelect)
        Me.spProp.Dock = DockStyle.Bottom
        Me.spProp.Location = New Point(0, &H76)
        Me.spProp.Name = "spProp"
        Me.spProp.Size = New Size(&HD0, 3)
        Me.spProp.TabIndex = &H11
        Me.spProp.TabStop = False
        Me.propGrid.CommandsVisibleIfAvailable = True
        Me.propGrid.Dock = DockStyle.Bottom
        Me.propGrid.LargeButtons = False
        Me.propGrid.LineColor = SystemColors.ScrollBar
        Me.propGrid.Location = New Point(0, &H79)
        Me.propGrid.Name = "propGrid"
        Me.propGrid.Size = New Size(&HD0, &HF8)
        Me.propGrid.TabIndex = 15
        Me.propGrid.Text = "propertyGrid1"
        Me.propGrid.ViewBackColor = SystemColors.Window
        Me.propGrid.ViewForeColor = SystemColors.WindowText
        AddHandler Me.propGrid.PropertyValueChanged, New PropertyValueChangedEventHandler(AddressOf Me.propGrid_PropertyValueChanged)
        Me.spltPictBox.Location = New Point(&HD0, &H1D)
        Me.spltPictBox.Name = "spltPictBox"
        Me.spltPictBox.Size = New Size(3, &H161)
        Me.spltPictBox.TabIndex = 15
        Me.spltPictBox.TabStop = False
        Me.printPrevDlg.AutoScrollMargin = New Size(0, 0)
        Me.printPrevDlg.AutoScrollMinSize = New Size(0, 0)
        Me.printPrevDlg.ClientSize = New Size(400, 300)
        Me.printPrevDlg.Enabled = True
        Me.printPrevDlg.Icon = DirectCast(resources.GetObject("printPrevDlg.Icon"), Icon)
        Me.printPrevDlg.Location = New Point(&H252, &H11)
        Me.printPrevDlg.MinimumSize = New Size(&H177, 250)
        Me.printPrevDlg.Name = "printPrevDlg"
        Me.printPrevDlg.TransparencyKey = Color.Empty
        Me.printPrevDlg.Visible = False
        Me.openFileDlg.DefaultExt = "*.dxf;*.dwg"
        Me.openFileDlg.Filter = "All(*.dxf,*.dwg,*.hpg,*.plt,*.rtl, *.spl, *.prn, *.gl2,*.hpgl2,*.hpgl,*.hp2,*.hp1, *.hp, *.plo, *.hg,*.hgl,*.cgm, *.gbr, *.bmp,*.jpg, *.jpeg,*.tiff, *.tif, *.gif, *.ico, *.cur, *.png, *.emf, *.wmf)|*.bmp;*.jpg;*.jpeg;*.tiff; *.tif; *.gif; *.ico;*.dxf;*.dwg;*.hpg;*.plt;*.rtl; *.spl; *.prn; *.gl2;*.hpgl2;*.hpgl;*.hp2;*.hp1; *.hp; *.plo; *.hg;*.hgl;*.cur;*.png; *.emf; *.wmf; *.cgm;*.gbr|CAD files(*.dxf, *.dwg)|*.dxf;*.dwg|All raster files (*.bmp,*.jpg, *.jpeg,*.tiff,*.tif, *.gif, *.ico, *.cur, *.png)|*.bmp;*.jpg;*.jpeg;*.tiff;*.tif; *.gif;*.ico;*.cur; *.png|Metafiles ( *.emf, *.wmf)| *.emf; *.wmf|DXF files(*.dxf)|*.dxf|DWG files(*.dwg)|*.dwg|BMP(*.bmp)|*.bmp|JPG(*.jpg, *.jpeg)| *.jpg; *.jpeg|TIFF(*.tiff, *.tif)|*.tiff;*.tif|GIF(*.gif)|*.gif|ICO(*.ico)|*.ico|PNG(*.png)|*.png|Cursors(*.cur)|*.cur|HPGL(*.hpg,*.plt,*.rtl, *.spl, *.prn, *.gl2,*.hpgl2,*.hpgl,*.hp2,*.hp1, *.hp, *.plo, *.hg,*.hgl)|*.hpg;*.plt;*.rtl; *.spl; *.prn; *.gl2;*.hpgl2;*.hpgl;*.hp2;*.hp1; *.hp; *.plo; *.hg;*.hgl|CGM (*.cgm)|*.cgm|Gerber (*.gbr)|*.gbr"
        Me.openFileDlg.ShowHelp = True
        Me.dlgSaveSerializeFile.Filter = "*.dat|*.dat"
        Me.dlgOpenSerializeFile.Filter = "*.dat|*.dat"
        Me.AutoScaleBaseSize = New Size(5, 13)
        Me.BackColor = SystemColors.Control
        MyBase.ClientSize = New Size(&H270, &H18E)
        MyBase.Controls.Add(Me.spltPictBox)
        MyBase.Controls.Add(Me.cadPictBox)
        MyBase.Controls.Add(Me.stBar)
        MyBase.Controls.Add(Me.trvPanel)
        MyBase.Controls.Add(Me.tlbTool)
        MyBase.Menu = Me.mainMenu
        MyBase.Name = "MainForm"
        Me.RightToLeft = RightToLeft.No
        MyBase.StartPosition = FormStartPosition.CenterScreen
        Me.Text = "CADImport.NET - Editor"
        MyBase.WindowState = FormWindowState.Maximized
        AddHandler MyBase.Resize, New System.EventHandler(AddressOf Me.MainForm_Resize)
        AddHandler MyBase.Closing, New CancelEventHandler(AddressOf Me.MainForm_Closing)
        AddHandler MyBase.Load, New System.EventHandler(AddressOf Me.MainForm_Load)
        AddHandler MyBase.Deactivate, New System.EventHandler(AddressOf Me.MainForm_Deactivate)
        Me.sbOpen.EndInit()
        Me.sbScale.EndInit()
        Me.sbCoord.EndInit()
        Me.trvPanel.ResumeLayout(False)
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Private Sub InitialNewPrintPages()
        Me.prtForm.Image = Me.cadImage
        Me.prtForm.CreateNewPages()
    End Sub

    Public Sub InitLng()
        Me.mlng = New MultipleLanguage(MyBase.GetType)
        If (Not Me.mainMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.mainMenu.MenuItems)
        End If
        If (Not Me.ContextMenu Is Nothing) Then
            Me.mlng.SaveNameMenuItem(Me.ContextMenu.MenuItems)
        End If
        Me.mlng.SaveNameNoNameElement(MyBase.Controls)
    End Sub

    Private Sub InitParams()
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.colorDraw = True
        Me.dimVisible = True
        Me.showLineWeight = True
        Me.textVisible = True
        Me.cntrlDown = False
        Me.startPt = Point.Empty
        Me.endPt = Point.Empty
        Me.PreviousPosition = PointF.Empty
    End Sub

    Private Sub InitParamsState()
        Me.clipRectangle = New ClipRect(Me.cadPictBox)
        Me.clipRectangle.MultySelect = True
        Me.SetAddEntityMode(CreatorType.Undetected)
        Me.entCreator = New EntitiesCreator(Me.cadPictBox, Color.White)
        CADImportFace.EntityPropertyGrid = Me.propGrid
        Me.lngFile = ApplicationConstants.defaultstr
        Me.curLngInd = 0
        Me.listItemSelectDel = New ListItemSelectEventHandler(AddressOf Me.ListSelect)
        AddHandler Me.cadPictBox.MouseWheel, New MouseEventHandler(AddressOf Me.CADPictBoxMouseWeel)
        AddHandler Me.cadPictBox.ScrollEvent, New ScrollEventHandlerExt(AddressOf Me.CADPictBoxScroll)
        AddHandler Me.cadPictBox.KeyDown, New KeyEventHandler(AddressOf Me.CADPictBoxKeyDown)
        AddHandler Me.cadPictBox.KeyUp, New KeyEventHandler(AddressOf Me.CADPictBoxKeyUp)
        Me.addEntity = -1
        Me.enableSnap = True
        AddHandler Me.entCreator.EndEntityDraw, New ChangeOptionsEventHandler(AddressOf Me.EndAddEntity)
        AddHandler Me.entCreator.CreateNewCADImageEvent, New CreateNewObjectEventHandler(AddressOf Me.CreateNewImage)
        AddHandler Me.entCreator.GetRealPointEvent, New GetRealPointEvent(AddressOf Me.GetRealPoint)
    End Sub

    Public Sub InitSettings()
        Me.svSet = New SaveSettings(MainForm.fileSettingsName)
        Me.settingsLst = Me.svSet.LoadOptions
        If (Not Me.settingsLst Is Nothing) Then
            Dim key As String = ApplicationConstants.languagepath
            If Me.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(Me.settingsLst.Item(key))
            End If
        Else
            Me.mlng.Path = CADConst.lngPathDefault
        End If
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (Me.settingsLst Is Nothing) Then
            Me.CreateNewSettingsList()
        Else
            Me.SetSettings()
        End If
    End Sub

    Private Sub InvalidateImage(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub LanguageSelect_Click(ByVal sender As Object, ByVal e As EventArgs)
        If TypeOf sender Is MenuItem Then
            Dim mn As MenuItem = CType(sender, MenuItem)
            Me.curLngInd = CByte(mn.Index)
            Me.lngFile = (mn.Text & ApplicationConstants.lngextstr)
            Me.SetAllFormsLanguageSettings()
            Me.SetLNG()
            Me.ChangeControlState()
        End If
    End Sub

    Private Sub ListSelect(ByVal item As ArrayList, ByVal e As ListEventSelectArgs)
        Dim itm1 As ListItem = Me.lForm.LayerList.Items.Item(e.ItemIndex)
        Dim index As Integer = Math.Floor(e.ItemIndex / Me.lForm.LayerList.Columns.Count)
        CADImportFace.SelectLayer(index, Me.cadImage)
        Select Case itm1.ImageIndex
            Case 3
                itm1.ImageIndex = 4
                Me.SetFreezeLayer(False, index)
                Exit Select
            Case 4
                itm1.ImageIndex = 3
                Me.SetFreezeLayer(True, index)
                Exit Select
            Case 7
                itm1.ImageIndex = 8
                Me.SetVisibleLayer(False, index)
                Exit Select
            Case 8
                itm1.ImageIndex = 7
                Me.SetVisibleLayer(True, index)
                Exit Select
        End Select
        If itm1.DrawColorRect Then
            Me.setColorDlg.Color = itm1.BackColor
            If (Me.setColorDlg.ShowDialog = DialogResult.OK) Then
                Me.SetColorLayer(Me.setColorDlg.Color, index)
                itm1.BackColor = Me.setColorDlg.Color
                Me.lForm.LayerList.InvalidateCell(e.ItemIndex)
            End If
        End If
        Me.lForm.LayerList.InvalidateCell(e.ItemIndex)
    End Sub

    Private Sub LoadEntities(ByVal deserializeObjects As SortedList, ByVal collectAdd As Object, ByVal section As String)
        Dim ent As CADEntity
        Dim entities As CADEntityCollection = Nothing
        Dim entitiesLst As SortedList = Nothing
        Dim layouts As CADLayoutCollection = Nothing
        If deserializeObjects.ContainsKey(section) Then
            If (section = ApplicationConstants.layoutsstr) Then
                layouts = DirectCast(deserializeObjects.Item(section), CADLayoutCollection)
            Else
                Dim tmp As Object = deserializeObjects.Item(section)
                entities = CType(tmp, CADEntityCollection)
                entitiesLst = CType(tmp, SortedList)
            End If
        End If
        If (Not entities Is Nothing) Then
            Dim i As Integer
            For i = 0 To entities.Count - 1
                ent = entities.Item(i)
                If (Not ent Is Nothing) Then
                    Me.LoadEntity(ent, True, collectAdd)
                End If
            Next i
        ElseIf (Not entitiesLst Is Nothing) Then
            Dim i As Integer
            For i = 0 To entitiesLst.Count - 1
                ent = CType(entitiesLst.GetByIndex(i), CADEntity)
                If (Not ent Is Nothing) Then
                    Me.LoadEntity(ent, True, collectAdd)
                End If
            Next i
        ElseIf (Not layouts Is Nothing) Then
            Dim i As Integer
            For i = 0 To layouts.Count - 1
                ent = layouts.Item(i)
                If (Not ent Is Nothing) Then
                    Me.LoadEntity(ent, True, collectAdd)
                End If
            Next i
        End If
    End Sub

    Private Sub LoadEntity(ByVal ent As CADEntity, ByVal detAdd As Boolean, ByVal collectAdd As Object)
        Dim ins As CADInsert = CType(ent, CADInsert)
        If TypeOf ent Is CADLeader Then
            ins = CType(ent, CADLeader).Insert
        End If
        If ((Not ins Is Nothing) AndAlso (Not ins.Block Is Nothing)) Then
            Dim i As Integer
            For i = 0 To ins.Block.Count - 1
                Me.LoadEntity(ins.Block.Entities.Item(i), False, collectAdd)
            Next i
        End If
        If Not TypeOf ent Is CADImageEnt Then
            ent.Loaded(Me.cadImage.Converter)
        End If
        Me.cadImage.Converter.OnCreate(ent)
        If detAdd Then
            If TypeOf collectAdd Is CADLayoutCollection Then
                Dim layout As CADLayout = CType(ent, CADLayout)
                Dim i As Integer
                For i = 0 To layout.Entities.Count - 1
                    Me.LoadEntity(layout.Entities.Item(i), False, collectAdd)
                Next i
                CType(collectAdd, CADLayoutCollection).Add(layout)
            ElseIf TypeOf collectAdd Is CADEntityCollection Then
                CType(collectAdd, CADEntityCollection).Add(ent)
            End If
        End If
    End Sub

    Public Sub LoadFile(ByVal dlg As Boolean)
        Me.SetPictureBoxLoadState(True, String.Empty)
        If (dlg AndAlso ((Me.openFileDlg.ShowDialog(Me) <> DialogResult.OK) OrElse (Me.openFileDlg.FileName Is Nothing))) Then
            Me.SetPictureBoxLoadState(False, String.Empty)
        Else
            Me.ClearCADImage()
            Me.cadImage = cadImage.CreateImageByExtension(Me.openFileDlg.FileName)
            If TypeOf Me.cadImage Is CADRasterImage Then
                CType(Me.cadImage, CADRasterImage).Control = Me.cadPictBox
            End If
            If (Me.cadImage Is Nothing) Then
                Me.SetPictureBoxLoadState(False, String.Empty)
            Else
                Try
                    If CADConst.IsWebPath(Me.openFileDlg.FileName) Then
                        Me.cadImage.LoadFromWeb(Me.openFileDlg.FileName)
                    Else
                        Me.cadImage.LoadFromFile(Me.openFileDlg.FileName)
                    End If
                Catch ex As Exception
                    MessageBox.Show(String.Format("[{0}] {1}", ex.Message, ex.StackTrace))
                End Try
                Me.SetCADImageOptions()
                Me.SetPictureBoxPosition(Me.Position)
                Me.EnableButton(True)
                Me.SetPictureBoxLoadState(False, Me.openFileDlg.FileName)
            End If
        End If
    End Sub

    Private Sub MainForm_Closing(ByVal sender As Object, ByVal e As CancelEventArgs)
        Me.CreateNewSettingsList()
        Me.svSet.SaveOptions(Me.settingsLst)
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.floatLicFrm.DisableFloating()
        Else
            Protection.CloseApplication()
        End If
    End Sub

    Private Sub MainForm_Deactivate(ByVal sender As Object, ByVal e As EventArgs)
        Me.detMouseDown = False
    End Sub

    Private Sub MainForm_Load(ByVal sender As Object, ByVal e As EventArgs)
        Me.shxFrm.AddDefaultSHXPaths()
        Me.VisibleAreaSize = New SizeF(Me.cadPictBox.Size.Width, Me.cadPictBox.Size.Height)
        If (Protection.LicenseType = LicenseType.Floating) Then
            Me.floatLicFrm.FloatingLicRegister()
        Else
            Protection.Register()
        End If
        If ((Not MainForm.fileName Is Nothing) AndAlso File.Exists(MainForm.fileName)) Then
            Me.openFileDlg.FileName = MainForm.fileName
            Me.LoadFile(False)
        End If
        Me.ChangeControlState()
    End Sub

    Private Sub MainForm_Resize(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoResize()
    End Sub

    Private Sub miAbout_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.aboutForm.ShowDialog()
    End Sub

    Private Sub miArcsSplit_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.UseWinEllipse()
        Me.ChangeControlState()
    End Sub

    Private Sub miBlackBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.Black_Click()
        Me.ChangeControlState()
    End Sub

    Private Sub miBlackDraw_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoBlackColor()
        Me.ChangeControlState()
    End Sub

    Private Sub miClose_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.CloseFile()
        Me.ChangeControlState()
    End Sub

    Private Sub miColorDraw_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoNormalColor()
        Me.ChangeControlState()
    End Sub

    Private Sub miCopy_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadImage.CopyEntities()
    End Sub

    Private Sub miCopyAsBMP_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.PutToClipboard()
    End Sub

    Private Sub miCut_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadImage.CutEntities()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miDelete_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.entCreator.Disable()
        Me.RemoveEntity()
        Me.stopSnap = True
    End Sub

    Private Sub miDeserializeEntities_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Me.dlgOpenSerializeFile.ShowDialog = DialogResult.OK) Then
            Dim detnew As Boolean = False
            If (Me.cadImage Is Nothing) Then
                Me.cadImage = New CADImage
                Me.cadImage.UseDoubleBuffering = False
                Me.cadImage.InitialNewImage()
                Me.cadImage.Converter.Layers.Clear()
                Me.cadImage.Converter.Layouts.Clear()
                detnew = True
            End If
            Dim deserializeObjects As SortedList = CType(Me.Deserialize(Me.dlgOpenSerializeFile.FileName), SortedList)
            If (Not deserializeObjects Is Nothing) Then
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.Layers, ApplicationConstants.layersstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.Layouts, ApplicationConstants.layoutsstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.Blocks, ApplicationConstants.blocksstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.VPorts, ApplicationConstants.vportsstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.LTypes, ApplicationConstants.ltypesstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.Converter.Styles, ApplicationConstants.stylesstr)
                Me.LoadEntities(deserializeObjects, Me.cadImage.CurrentLayout.Entities, ApplicationConstants.entitiesstr)
                Me.cadImage.GetExtents()
                If detnew Then
                    Me.SetCADImageOptions()
                    Me.SetPictureBoxPosition(Me.Position)
                    Me.EnableButton(True)
                    Me.SetPictureBoxLoadState(False, Me.openFileDlg.FileName)
                Else
                    If Me.trvPanel.Visible Then
                        Me.trvEntity.Nodes.Clear()
                        CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImage)
                    End If
                    Me.DoResize()
                End If
            End If
        End If
    End Sub

    Private Sub miDimShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.ChangeDimensionsVisiblity()
        Me.ChangeControlState()
    End Sub

    Private Sub miEntitiesTree_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.ChangeTreeVisiblity(Not Me.trvEntity.Visible)
        Me.ChangeControlState()
    End Sub

    Private Sub miExit_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.Close()
    End Sub

    Private Sub miFit_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.GetExtents()
    End Sub

    Private Sub miFloatLic_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.floatLicFrm.ShowDialog()
    End Sub

    Private Sub miLayersShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.SetLayList()
        Me.lForm.ShowDialog()
    End Sub

    Private Sub miOpenFile_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.LoadFile(True)
    End Sub

    Private Sub miOptions_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.entCreator.OptionsForm.ShowDialog()
    End Sub

    Private Sub miPaste_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadImage.PasteEntities()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub miPrint_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.cadImage.Print(True, True)
    End Sub

    Private Sub miPrintCustom_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoExtentsForPrint()
        Me.prtForm.ShowDialog()
    End Sub

    Private Sub miPrintPreview_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoExtentsForPrint()
        Me.prtForm.TypePage = CADImport.Printing.DrawingSize.Fit
        Me.printPrevDlg.Document = Me.prtForm.Print(False)
        Me.printPrevDlg.ShowDialog()
        If (Not Me.printPrevDlg.Document Is Nothing) Then
            Me.printPrevDlg.Document.Dispose()
        End If
    End Sub

    Private Sub miRedo_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.RedoChangeEntity()
    End Sub

    Private Sub miRegister_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.regFrm.ShowDialog()
    End Sub

    Private Sub miSaveAsDXF_Click(ByVal sender As Object, ByVal e As EventArgs)
        If ((Not Me.cadImage Is Nothing) AndAlso (Me.saveDXFDlg.ShowDialog = DialogResult.OK)) Then
            Me.SaveAsDXF(Me.saveDXFDlg.FileName)
        End If
    End Sub

    Private Sub miSaveFile_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.SaveAsImage()
    End Sub

    Private Sub miSerializeEntities_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadImage Is Nothing) Then
            Dim name As String = Me.cadImage.Converter.Source
            If (Not name Is Nothing) Then
                name = Path.GetFileName(name).Replace(Path.GetExtension(name), ApplicationConstants.datextstr)
                Me.dlgSaveSerializeFile.FileName = name
            End If
            If (Me.dlgSaveSerializeFile.ShowDialog = DialogResult.OK) Then
                Dim serializeObjects As New SortedList
                Dim detsel As Boolean = False
                If (Me.cadImage.SelectEntitiesCount <> 0) Then
                    detsel = True
                End If
                If detsel Then
                    serializeObjects.Add(ApplicationConstants.entitiesstr, Me.cadImage.SelectedEntities)
                Else
                    serializeObjects.Add(ApplicationConstants.entitiesstr, Me.cadImage.Converter.Entities)
                End If
                serializeObjects.Add(ApplicationConstants.blocksstr, Me.cadImage.Converter.Blocks)
                serializeObjects.Add(ApplicationConstants.vportsstr, Me.cadImage.Converter.VPorts)
                serializeObjects.Add(ApplicationConstants.ltypesstr, Me.cadImage.Converter.LTypes)
                serializeObjects.Add(ApplicationConstants.layoutsstr, Me.cadImage.Converter.Layouts)
                serializeObjects.Add(ApplicationConstants.layersstr, Me.cadImage.Converter.Layers)
                serializeObjects.Add(ApplicationConstants.stylesstr, Me.cadImage.Converter.Styles)
                serializeObjects.Add(ApplicationConstants.xrefsstr, Me.cadImage.Converter.XRefs)
                Me.Serialize(Me.dlgSaveSerializeFile.FileName, serializeObjects)
            End If
        End If
    End Sub

    Private Sub miShowLineWeight_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.ChangeShowLineWeight()
        Me.ChangeControlState()
    End Sub

    Private Sub miSHXFontsPaths_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.shxFrm.ShowDialog()
    End Sub

    Private Sub miTextsShow_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.ChangeTextsVisiblity()
        Me.ChangeControlState()
    End Sub

    Private Sub miUndo_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.UndoChangeEntity()
    End Sub

    Private Sub miWhiteBack_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.White_Click()
        Me.ChangeControlState()
    End Sub

    Private Sub miZoom_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Not Me.cadImage Is Nothing) Then
            Dim i As Single = Me.ImageScale
            Select Case CType(sender, MenuItem).Index
                Case 0
                    i = 0.1!
                    Exit Select
                Case 1
                    i = 0.25!
                    Exit Select
                Case 2
                    i = 0.5!
                    Exit Select
                Case 3
                    i = 1.0!
                    Exit Select
                Case 4
                    i = 2.0!
                    Exit Select
                Case 5
                    i = 4.0!
                    Exit Select
                Case 6
                    i = 8.0!
                    Exit Select
            End Select
            Me.ResetScaling()
            Me.PreviousPosition = New PointF((CSng(Me.cadPictBox.ClientRectangle.Width) / 2.0!), (CSng(Me.cadPictBox.ClientRectangle.Height) / 2.0!))
            Me.ImageScale = i
            Me.cadPictBox.Invalidate()
            Me.SetPictureBoxPosition(Me.Position)
        End If
    End Sub

    Private Sub miZoomIn_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoZoomIn()
    End Sub

    Private Sub miZoomOut_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoZoomOut()
    End Sub

    Public Sub MoveEntity(ByVal x1 As Integer, ByVal y1 As Integer, ByVal x2 As Integer, ByVal y2 As Integer)
        Me.endPt.X = x1
        Me.endPt.Y = y1
        Me.startPt.X = x2
        Me.startPt.Y = y2
        Me.SetNewEntityPosition()
    End Sub

    Private Sub MoveToPosition(ByRef point As DPoint, ByVal aPos As DPoint, ByVal direction As Integer)
        point.X = (point.X + (direction * aPos.X))
        point.Y = (point.Y + (direction * aPos.Y))
        point.Z = (point.Z + (direction * aPos.Z))
    End Sub

    Private Function MultipleSelect() As Boolean
        If (Me.cadImage.SelectionMode = SelectionEntityMode.Enabled) Then
            Dim l As Integer = Me.clipRectangle.ClientRectangle.Left
            Dim t As Integer = Me.clipRectangle.ClientRectangle.Top
            Dim pt1 As DPoint = Me.GetRealPoint(l, t)
            Dim pt2 As DPoint = Me.GetRealPoint(Me.clipRectangle.ClientRectangle.Right, Me.clipRectangle.ClientRectangle.Bottom)
            Dim tmpRect As New DRect(pt1.X, pt1.Y, pt2.X, pt2.Y)
            Dim rg As Region = Me.cadImage.GetSelectEntityRegion(New Rectangle(l, t, Me.clipRectangle.ClientRectangle.Width, Me.clipRectangle.ClientRectangle.Height))
            Me.propGrid.SelectedObject = New ObjEntities(Me.cadImage.MultipleSelectExt(tmpRect, True, True))
            Me.cadPictBox.Invalidate(rg)
            rg.Dispose()
            Return True
        End If
        Return False
    End Function

    Private Sub Open_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.LoadFile(True)
        Me.ChangeControlState()
    End Sub

    Private Sub propGrid_PropertyValueChanged(ByVal s As Object, ByVal e As PropertyValueChangedEventArgs)
        Me.cadImage.ClearMarkers()
        Me.cadImage.DoSelectEntities(Me.cadImage.SelectedEntities)
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub PutToClipboard()
        If Me.clipRectangle.Enabled Then
            Dim tmpRect As DRect = Me.ImageDRect
            Me.cadImage.SaveImageToClipboard(tmpRect, Me.clipRectangle.ClientRectangle)
        Else
            Dim tmp As New DRect(0, 0, CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
            Me.cadImage.SaveImageToClipboard(tmp)
        End If
    End Sub

    Private Sub RedoChangeEntity()
        Me.cadImage.Redo()
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ReloadLNG()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
    End Sub

    Public Sub ReloadLNG(ByVal val As String)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.Path = val
        If (Me.mlng.Language = String.Empty) Then
            Me.curLngInd = 7
        End If
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        If (Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Count > Me.curLngInd) Then
            Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Item(Me.curLngInd).Checked = True
        End If
    End Sub

    Private Sub RemoveEntity()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.RemoveEntity()
        End If
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ReOpen()
        If ((Not Me.openFileDlg.FileName Is Nothing) AndAlso File.Exists(Me.openFileDlg.FileName)) Then
            Me.LoadFile(False)
        End If
    End Sub

    Public Sub ResetScaling()
        Me.ImageScale = 1.0!
        Me.ImagePreviousScale = 1.0!
        Me.LeftImagePosition = ((Me.cadPictBox.ClientRectangle.Width - Me.VisibleAreaSize.Width) / 2.0!)
        Me.TopImagePosition = ((Me.cadPictBox.ClientRectangle.Height - Me.VisibleAreaSize.Height) / 2.0!)
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub SaveAsDXF(ByVal fName As String)
        Dim exp1 As CADImport.Export.DirectCADtoDXF.CADtoDXF
        If ((Not Me.cadImage Is Nothing) AndAlso Not TypeOf Me.cadImage Is CADRasterImage) Then
            exp1 = New CADImport.Export.DirectCADtoDXF.CADtoDXF(Me.cadImage)
            exp1.SaveToFile(fName)
        End If
    End Sub

    Public Sub SaveAsImage()
        If ((Not Me.cadImage Is Nothing) AndAlso (Me.saveImgDlg.ShowDialog = DialogResult.OK)) Then
            Dim tmpRect As New DRect(0, 0, CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
            Dim imgFrm As ImageFormat = ImageFormat.Bmp
            If (Not Me.saveImgDlg.FileName Is Nothing) Then
                Dim tmp As String = Me.saveImgDlg.FileName
                If (tmp.ToUpper.IndexOf(ApplicationConstants.jpgextstr) <> -1) Then
                    imgFrm = ImageFormat.Jpeg
                End If
                If (tmp.ToUpper.IndexOf(ApplicationConstants.bmpextstr) <> -1) Then
                    imgFrm = ImageFormat.Bmp
                End If
                If (tmp.ToUpper.IndexOf(ApplicationConstants.tiffextstr) <> -1) Then
                    imgFrm = ImageFormat.Tiff
                End If
                If (tmp.ToUpper.IndexOf(ApplicationConstants.gifextstr) <> -1) Then
                    imgFrm = ImageFormat.Gif
                End If
                If (tmp.ToUpper.IndexOf(ApplicationConstants.emfextstr) <> -1) Then
                    imgFrm = ImageFormat.Emf
                End If
                If (tmp.ToUpper.IndexOf(ApplicationConstants.dxfextstr) <> -1) Then
                    Me.SaveAsDXF(Me.saveImgDlg.FileName)
                Else
                    If Not Me.clipRectangle.Enabled Then
                        Me.rasterSizeForm.Image = Me.cadImage
                        Me.rasterSizeForm.CurrentSize = tmpRect
                        Me.rasterSizeForm.SaveFileName = Me.saveImgDlg.FileName
                        If (Me.rasterSizeForm.ShowDialog = DialogResult.OK) Then
                            tmpRect = Me.rasterSizeForm.SizeImage
                        End If
                    End If
                    Dim tmpNumberOfPartsInCircle As Integer = Me.cadImage.NumberOfPartsInCircle
                    Me.cadImage.NumberOfPartsInCircle = CADConst.SetNumberOfPartsInCurve(tmpRect)
                    If Me.clipRectangle.Enabled Then
                        tmpRect = Me.ImageDRect
                        If ((imgFrm Is ImageFormat.Emf) OrElse (imgFrm Is ImageFormat.Wmf)) Then
                            Me.cadImage.ExportToMetafile(Me.saveImgDlg.FileName, tmpRect, Me.clipRectangle.ClientRectangle)
                        Else
                            Me.cadImage.SaveToFile(Me.saveImgDlg.FileName, imgFrm, tmpRect, Me.clipRectangle.ClientRectangle, Me.rasterSizeForm.ImagePixelFormat)
                        End If
                    ElseIf ((imgFrm Is ImageFormat.Emf) OrElse (imgFrm Is ImageFormat.Wmf)) Then
                        Me.cadImage.ExportToMetafile(Me.saveImgDlg.FileName, tmpRect)
                    Else
                        Me.cadImage.SaveToFile(Me.saveImgDlg.FileName, imgFrm, tmpRect, Me.rasterSizeForm.ImagePixelFormat)
                    End If
                    Me.cadImage.NumberOfPartsInCircle = tmpNumberOfPartsInCircle
                    If (Not TypeOf Me.cadImage Is CADRasterImage AndAlso Not Me.clipRectangle.Enabled) Then
                        Me.DoResize()
                    End If
                End If
            End If
        End If
    End Sub

    Public Function SelectEntity(ByVal x As Integer, ByVal y As Integer) As Boolean
        If Not Me.CreateNewEntity Then
            Me.moveMarker = False
            If (Me.cadImage Is Nothing) Then
                Return False
            End If
            Dim det As Boolean = (Me.cadImage.SelectEntitiesCount = 0)
            If (Not Me.cadImage.SelectExt(x, y, Not Me.cntrlDown, True) Is Nothing) Then
                Me.moveMarker = True
                Me.stopSnap = True
            ElseIf Not det Then
                Me.stopSnap = True
            End If
        End If
        Return False
    End Function

    Public Sub Serialize(ByVal fileName As String, ByVal sender As Object)
        Dim stm As Stream = File.Open(fileName, FileMode.Create, FileAccess.ReadWrite)
        Dim bf1 As BinaryFormatter = New BinaryFormatter
        bf1.Serialize(stm, sender)
        stm.Close()
    End Sub

    Private Sub SetAddEntityMode(ByVal val As CreatorType)
        Dim tmpVal As Integer = Me.addEntity
        Me.addEntity = -1
        Select Case val
            Case CreatorType.Image
                If (tmpVal <> 0) Then
                    Me.addEntity = 0
                End If
                Exit Select
            Case CreatorType.Solid
                If (tmpVal <> 1) Then
                    Me.addEntity = 1
                End If
                Exit Select
            Case CreatorType.Line
                If (tmpVal <> 2) Then
                    Me.addEntity = 2
                End If
                Exit Select
            Case CreatorType.Rectangle
                If (tmpVal <> 3) Then
                    Me.addEntity = 3
                End If
                Exit Select
            Case CreatorType.Ellipse
                If (tmpVal <> 4) Then
                    Me.addEntity = 4
                End If
                Exit Select
            Case CreatorType.Text
                If (tmpVal <> 5) Then
                    Me.addEntity = 5
                End If
                Exit Select
            Case CreatorType.Polyline
                If (tmpVal <> 6) Then
                    Me.addEntity = 6
                End If
                Exit Select
            Case CreatorType.Pen
                If (tmpVal <> 7) Then
                    Me.addEntity = 7
                End If
                Exit Select
            Case CreatorType.MText
                If (tmpVal <> 10) Then
                    Me.addEntity = 10
                End If
                Exit Select
            Case CreatorType.Point
                If (tmpVal <> 11) Then
                    Me.addEntity = 11
                End If
                Exit Select
            Case CreatorType.Cloud
                If (tmpVal <> 9) Then
                    Me.addEntity = 9
                End If
                Exit Select
            Case CreatorType.Hatch
                If (tmpVal <> 8) Then
                    Me.addEntity = 8
                End If
                Exit Select
        End Select
    End Sub

    Public Sub SetAllFormsLanguageSettings()
        Me.entCreator.OptionsForm.MultipleLanguagesPath = Me.mlng.Path
        Me.entCreator.OptionsForm.LngFileName = Me.lngFile
        Me.aboutForm.MultipleLanguagesPath = Me.mlng.Path
        Me.aboutForm.LngFileName = Me.lngFile
        Me.floatLicFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.floatLicFrm.LngFileName = Me.lngFile
        Me.lForm.MultipleLanguagesPath = Me.mlng.Path
        Me.lForm.LngFileName = Me.lngFile
        Me.prtForm.MultipleLanguagesPath = Me.mlng.Path
        Me.prtForm.LngFileName = Me.lngFile
        Me.regFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.regFrm.LngFileName = Me.lngFile
        Me.rasterSizeForm.MultipleLanguagesPath = Me.mlng.Path
        Me.rasterSizeForm.LngFileName = Me.lngFile
        Me.shxFrm.MultipleLanguagesPath = Me.mlng.Path
        Me.shxFrm.LngFileName = Me.lngFile
    End Sub

    Public Sub SetCADImageOptions()
        Me.SetSnapMode()
        Me.cadImage.SelectionMode = SelectionEntityMode.Enabled
        Me.cadImage.UseDoubleBuffering = False
        Me.cadImage.UseWinEllipse = False
        If (Me.cadPictBox.BackColor.Equals(Color.White)) Then
            Me.White_Click()
        Else
            Me.Black_Click()
        End If
        Me.ViewLayouts()
        If Me.trvPanel.Visible Then
            CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImage)
        End If
        If Not Me.colorDraw Then
            Me.DoBlackColor()
        End If
        Me.SetLayList()
        Me.DoResize()
        ObjEntity.cadImage = Me.cadImage
        Me.prtForm.Image = Me.cadImage
        ObjEntity.propGrid = Me.propGrid
        Me.entCreator.Image = Me.cadImage
    End Sub

    Public Sub SetColorLayer(ByVal color As Color, ByVal index As Integer)
        Me.cadImage.SetLayerColor(index, color, Me.lForm.detInvalidate)
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub SetEnableChecked()
        Me.tlbTool.Buttons.Item(8).Pushed = (Me.addEntity = 0)
        Me.tlbTool.Buttons.Item(9).Pushed = (Me.addEntity = 1)
        Me.tlbTool.Buttons.Item(10).Pushed = (Me.addEntity = 2)
        Me.tlbTool.Buttons.Item(11).Pushed = (Me.addEntity = 3)
        Me.tlbTool.Buttons.Item(12).Pushed = (Me.addEntity = 4)
        Me.tlbTool.Buttons.Item(13).Pushed = (Me.addEntity = 5)
        Me.tlbTool.Buttons.Item(14).Pushed = (Me.addEntity = 6)
        Me.tlbTool.Buttons.Item(15).Pushed = (Me.addEntity = 7)
        Me.tlbTool.Buttons.Item(&H10).Pushed = (Me.addEntity = 8)
        Me.tlbTool.Buttons.Item(&H11).Pushed = (Me.addEntity = 9)
        Me.tlbTool.Buttons.Item(&H12).Pushed = (Me.addEntity = 10)
        Me.tlbTool.Buttons.Item(&H13).Pushed = (Me.addEntity = 11)
    End Sub

    Public Sub SetFreezeLayer(ByVal visible As Boolean, ByVal index As Integer)
        Me.cadImage.SetLayerFreeze(index, visible, Me.lForm.detInvalidate)
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub SetLayList()
        If ((Me.lForm.LayerList.Items.Count = 0) AndAlso (Not Me.cadImage Is Nothing)) Then
            ObjEntity.LayersList = New String(Me.cadImage.LayersCount - 1) {}
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr1, ApplicationConstants.namestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr2, ApplicationConstants.visiblestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr4, ApplicationConstants.freezestr, 0))
            Me.lForm.LayerList.Columns.Add(New ListHeader(ApplicationConstants.headstr3, ApplicationConstants.colorstr, 0))
            Dim I As Integer
            For I = 0 To Me.cadImage.LayersCount - 1
                Dim tmp As String = Me.cadImage.GetLayerName(I)
                Dim colorLay As Color = Me.cadImage.GetLayerColor(I)
                ObjEntity.LayersList(I) = tmp
                Me.AddRecordToLayerList(tmp, colorLay, Me.cadImage.GetLayerVisible(I), Me.cadImage.GetLayerFreeze(I))
            Next I
            Me.lForm.LayerList.SetAutoSize()
            AddHandler Me.lForm.LayerList.SelectItemEvent, Me.listItemSelectDel
        End If
    End Sub

    Public Sub SetLNG()
        Me.mlng.LoadLNG(Me.lngFile)
        Me.mlng.RestoreLanguage(MyBase.Controls, MyBase.Menu)
        Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0).MenuItems.Clear()
        Me.mlng.LoadLngFileList(Me.mainMenu.MenuItems.Item(4).MenuItems.Item(0), New System.EventHandler(AddressOf Me.LanguageSelect_Click))
        Me.Text = ApplicationConstants.appnamestr
        Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
    End Sub

    Public Sub SetNewEntityPosition()
        If ((Me.startPt.X <> 0) OrElse (Me.StartPoint.Y <> 0)) Then
            Dim p1 As DPoint = Me.GetRealPoint(Me.endPt.X, Me.EndPoint.Y)
            Dim p2 As DPoint = Me.GetRealPoint((Me.endPt.X - Me.StartPoint.X), (Me.EndPoint.Y - Me.StartPoint.Y))
            Me.cadImage.SetNewPosEntitiesExt((p2.X - p1.X), (p2.Y - p1.Y), (p2.Z - p1.Z), Me.cadPictBox.CreateGraphics)
            Me.startPt.X = 0
            Me.startPt.Y = 0
            Me.endPt.X = 0
            Me.endPt.Y = 0
        End If
    End Sub

    Public Sub SetNewMarkerPosition()
        If ((Me.startPt.X <> 0) OrElse (Me.StartPoint.Y <> 0)) Then
            Dim p1 As DPoint = Me.GetRealPoint(Me.endPt.X, Me.EndPoint.Y)
            Dim p2 As DPoint = Me.GetRealPoint((Me.endPt.X - Me.StartPoint.X), (Me.EndPoint.Y - Me.StartPoint.Y))
            If Me.cadImage.EnableSnap Then
                p2 = Me.cadImage.SnapRealPoint
            End If
            Me.cadImage.SetNewEntityMarkerPos((p2.X - Me.cadImage.CurrentMarker.Point.X), (p2.Y - Me.cadImage.CurrentMarker.Point.Y), p1.Z)
            Me.startPt.X = 0
            Me.startPt.Y = 0
            Me.endPt.X = 0
            Me.endPt.Y = 0
        End If
    End Sub

    Private Sub SetPictureBoxLoadState(ByVal val As Boolean, ByVal name As String)
        If val Then
            Me.Cursor = Cursors.WaitCursor
            Me.cadPictBox.Visible = False
            Me.stBar.Panels.Item(0).Text = ApplicationConstants.loadfilestr
        Else
            Me.Cursor = Cursors.Default
            Me.cadPictBox.Visible = True
            If (name <> String.Empty) Then
                Me.stBar.Panels.Item(0).Text = name
            End If
        End If
    End Sub

    Private Sub SetPictureBoxPosition(ByVal value As PointF)
        Dim w1 As Integer
        Dim h1 As Integer
        If (value.X > 0.0!) Then
            w1 = 0
        Else
            w1 = CInt(Math.Abs(value.X))
        End If
        If (w1 > Me.cadPictBox.VirtualSize.Width) Then
            w1 = Me.cadPictBox.VirtualSize.Width
        End If
        If (value.Y > 0.0!) Then
            h1 = 0
        Else
            h1 = CInt(Math.Abs(value.Y))
        End If
        If (h1 > Me.cadPictBox.VirtualSize.Height) Then
            h1 = Me.cadPictBox.VirtualSize.Height
        End If
        Me.cadPictBox.SetPositionNoInvalidate(New Point(w1, h1))
    End Sub

    Public Sub SetSettings()
        If (Not Me.settingsLst Is Nothing) Then
            Dim cn As Integer = 0
            Dim key As String = ApplicationConstants.languagepath
            If Me.settingsLst.ContainsKey(key) Then
                Me.mlng.Path = Convert.ToString(Me.settingsLst.Item(key))
                Me.entCreator.OptionsForm.LngDir = Me.mlng.Path
            End If
            key = ApplicationConstants.languagestr
            If Me.settingsLst.ContainsKey(key) Then
                Me.lngFile = CStr(Me.settingsLst.Item(key))
            End If
            Me.mlng.LoadLNG(Me.lngFile)
            Me.Text = Me.mlng.SetLanguage(MyBase.Controls, MyBase.Menu, Me.Text)
            key = ApplicationConstants.languageIDstr
            If Me.settingsLst.ContainsKey(key) Then
                Me.curLngInd = Convert.ToByte(Me.settingsLst.Item(key))
            End If
            key = ApplicationConstants.backcolorstr
            Dim tmp As String = ApplicationConstants.blackstr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.blackstr) Then
                Me.Black_Click()
            Else
                Me.White_Click()
            End If
            key = ApplicationConstants.showentitystr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.spltPictBox.Visible = True
                Me.trvPanel.Visible = True
            Else
                Me.spltPictBox.Visible = False
                Me.trvPanel.Visible = False
            End If
            key = ApplicationConstants.colordrawstr
            If Me.settingsLst.ContainsKey(key) Then
                tmp = Convert.ToString(Me.settingsLst.Item(key))
            End If
            If (tmp.ToUpper = ApplicationConstants.truestr) Then
                Me.colorDraw = True
            Else
                Me.colorDraw = False
            End If
            key = ApplicationConstants.shxpathcnstr
            If Me.settingsLst.ContainsKey(key) Then
                cn = Convert.ToInt32(Me.settingsLst.Item(key))
            End If
            Dim i As Integer
            For i = 0 To cn - 1
                key = String.Format("SHXPath_{0}", (i + 1))
                If Me.settingsLst.ContainsKey(key) Then
                    Me.shxFrm.AddPath(Convert.ToString(Me.settingsLst.Item(key)))
                End If
            Next i
            key = ApplicationConstants.installstr
            If (Me.settingsLst.ContainsKey(key) AndAlso CADConst.SearchSHXPaths) Then
                Me.shxFrm.lstDir.Items.Clear()
                Me.shxFrm.lstPath.Clear()
                Dim vPaths As New ArrayList
                CADConst.FindAutoCADSHXPaths(vPaths)
                For i = 0 To vPaths.Count - 1
                    tmp = CStr(vPaths.Item(i))
                    Me.shxFrm.lstDir.Items.Add(tmp)
                    Me.shxFrm.lstPath.Add(tmp, String.Empty)
                    CADConst.SHXSearchPaths = (CADConst.SHXSearchPaths & CADConst.SHXSearchPaths & tmp & ApplicationConstants.sepstr3)
                Next i
            End If
            key = "Type_license"
            If Me.settingsLst.ContainsKey(key) Then
                tmp = CStr(Me.settingsLst.Item(key))
                If (tmp = "floating") Then
                    Protection.LicenseType = LicenseType.Floating
                    key = "Host"
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.Host = CStr(Me.settingsLst.Item(key))
                    End If
                    key = "Port"
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.Port = Convert.ToInt32(Me.settingsLst.Item(key))
                    End If
                    key = "Application"
                    If Me.settingsLst.ContainsKey(key) Then
                        Me.floatLicFrm.App = CStr(Me.settingsLst.Item(key))
                    End If
                Else
                    Protection.LicenseType = LicenseType.Register
                End If
            End If
        End If
    End Sub

    Public Sub SetSizePictureBox(ByVal sz As Size)
        Me.cadPictBox.SetVirtualSizeNoInvalidate(sz)
    End Sub

    Public Sub SetSnapMode()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.EnableSnap = Me.enableSnap
        End If
    End Sub

    Public Sub SetVisibleLayer(ByVal visible As Boolean, ByVal index As Integer)
        Me.cadImage.SetLayerVisible(index, visible, Me.lForm.detInvalidate)
        Me.cadImage.ClearSelection()
        Me.cadImage.ClearMarkers()
        Me.InitialNewPrintPages()
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub Shift()
        Me.LeftImagePosition = (Me.PreviousPosition.X - (((Me.PreviousPosition.X - Me.LeftImagePosition) * Me.ImageScale) / Me.ImagePreviousScale))
        Me.TopImagePosition = (Me.PreviousPosition.Y - (((Me.PreviousPosition.Y - Me.TopImagePosition) * Me.ImageScale) / Me.ImagePreviousScale))
        Me.ImagePreviousScale = Me.ImageScale
    End Sub

    Private Sub tlbTool_ButtonClick(ByVal sender As Object, ByVal e As ToolBarButtonClickEventArgs)
        Select Case Me.tlbTool.Buttons.IndexOf(e.Button)
            Case 0
                Me.LoadFile(True)
                Exit Select
            Case 1
                Me.DoZoomIn()
                Exit Select
            Case 2
                Me.DoZoomOut()
                Exit Select
            Case 3
                Me.White_Click()
                Exit Select
            Case 4
                Me.Black_Click()
                Exit Select
            Case 5
                Me.SetLayList()
                Me.lForm.ShowDialog()
                Exit Select
            Case 6
                Me.SaveAsImage()
                Exit Select
            Case 7
                If (MessageBox.Show(ApplicationConstants.messagestr, ApplicationConstants.appnamestr, MessageBoxButtons.YesNo) = DialogResult.Yes) Then
                    Me.ChangeTextsType(Not Me.useSHXFonts)
                End If
                Exit Select
            Case 8
                Me.SetAddEntityMode(CreatorType.Image)
                Exit Select
            Case 9
                Me.SetAddEntityMode(CreatorType.Solid)
                Exit Select
            Case 10
                Me.SetAddEntityMode(CreatorType.Line)
                Exit Select
            Case 11
                Me.SetAddEntityMode(CreatorType.Rectangle)
                Exit Select
            Case 12
                Me.SetAddEntityMode(CreatorType.Ellipse)
                Exit Select
            Case 13
                Me.SetAddEntityMode(CreatorType.Text)
                Exit Select
            Case 14
                Me.SetAddEntityMode(CreatorType.Polyline)
                Exit Select
            Case 15
                Me.SetAddEntityMode(CreatorType.Pen)
                Exit Select
            Case &H10
                Me.SetAddEntityMode(CreatorType.Hatch)
                Exit Select
            Case &H11
                Me.SetAddEntityMode(CreatorType.Cloud)
                Exit Select
            Case &H12
                Me.SetAddEntityMode(CreatorType.MText)
                Exit Select
            Case &H13
                Me.SetAddEntityMode(CreatorType.Point)
                Exit Select
            Case 20
                Me.entCreator.OptionsForm.ShowDialog()
                Exit Select
            Case &H15
                Me.CreateNewImage()
                Exit Select
            Case &H16
                Me.GetExtents()
                Exit Select
            Case &H17
                Me.RemoveEntity()
                Exit Select
            Case &H18
                Me.UndoChangeEntity()
                Exit Select
            Case &H19
                Me.RedoChangeEntity()
                Exit Select
            Case &H1A
                Me.enableSnap = Not Me.enableSnap
                Me.SetSnapMode()
                Exit Select
        End Select
        Me.SetEnableChecked()
        Me.ChangeControlState()
    End Sub

    Private Sub trvEntity_AfterCheck(ByVal sender As Object, ByVal e As TreeViewEventArgs)
        CADImportFace.DoCheckTreeNode(Me.trvEntity.Nodes, e.Node, Me.cadImage, Me.cadPictBox)
        Me.cadPictBox.Invalidate()
    End Sub

    Private Sub trvEntity_AfterSelect(ByVal sender As Object, ByVal e As TreeViewEventArgs)
        CADImportFace.DecodeEntity(e.Node, Me.cadImage, Me.cadPictBox, Me.ImageScale)
    End Sub

    Private Sub UndoChangeEntity()
        Me.cadImage.Undo()
        CADImportFace.LoadTreeNodes(Me.trvEntity.Nodes, Me.cadImage)
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub UseClipRect()
        If (((Me.clipRectangle.ClientRectangle.Width > 10) AndAlso (Me.clipRectangle.ClientRectangle.Height > 10)) AndAlso Not Me.MultipleSelect) Then
        End If
    End Sub

    Public Sub UseWinEllipse()
        Me.cadImage.UseWinEllipse = Not Me.cadImage.UseWinEllipse
        Me.cadPictBox.Invalidate()
    End Sub

    Public Sub ViewLayouts()
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.SetCurrentLayout(Me.cadImage.DefaultLayoutIndex)
        End If
    End Sub

    Public Sub White_Click()
        Me.cadPictBox.BackColor = Color.White
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.BackgroundColor = Color.White
        End If
        Me.trvEntity.BackColor = Color.White
        Me.trvEntity.ForeColor = Color.Black
        If (Not Me.cadImage Is Nothing) Then
            Me.cadImage.DefaultColor = Color.Black
        End If
        If (Not Me.clipRectangle Is Nothing) Then
            Me.clipRectangle.Color = Color.Black
        End If
    End Sub

    Public Sub Zoom(ByVal i As Single)
        If (Not Me.cadImage Is Nothing) Then
            Me.ImageScale = (Me.ImageScale * i)
            If (Me.ImageScale < 0.005!) Then
                Me.ImageScale = 0.005!
            End If
            Me.cadPictBox.Invalidate()
            Me.stopSnap = True
            Me.entCreator.Disable()
        End If
    End Sub

    Private Sub ZoomIn_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoZoomIn()
    End Sub

    Private Sub ZoomOut_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.DoZoomOut()
    End Sub


    ' Properties
    Public ReadOnly Property CreateNewEntity() As Boolean
        Get
            If ((Me.cadImage Is Nothing) AndAlso (Me.addEntity = 8)) Then
                Return False
            End If
            If (((Not Me.cadImage Is Nothing) AndAlso (Me.cadImage.SelectedEntities.Count = 0)) AndAlso (Me.addEntity = 8)) Then
                Return False
            End If
            Return (Me.addEntity <> -1)
        End Get
    End Property

    Public ReadOnly Property EditorCADPictureBox() As CADPictureBox
        Get
            Return Me.cadPictBox
        End Get
    End Property

    Public Property EndPoint() As Point
        Get
            Return Me.endPt
        End Get
        Set(ByVal value As Point)
            Me.endPt = value
        End Set
    End Property

    Public ReadOnly Property Image() As cadImage
        Get
            Return Me.cadImage
        End Get
    End Property

    Public ReadOnly Property ImageDRect() As DRect
        Get
            Return New DRect(CDbl(Me.pos.X), CDbl(Me.pos.Y), CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)), CDbl((Me.VisibleAreaSize.Height * Me.ImageScale)))
        End Get
    End Property

    Public Property ImagePreviousScale() As Single
        Get
            Return Me.prev_sc
        End Get
        Set(ByVal value As Single)
            Me.prev_sc = value
        End Set
    End Property

    Public ReadOnly Property ImageRectangleF() As RectangleF
        Get
            Return New RectangleF(Me.pos.X, Me.pos.Y, (Me.VisibleAreaSize.Width * Me.ImageScale), (Me.VisibleAreaSize.Height * Me.ImageScale))
        End Get
    End Property

    Public Property ImageScale() As Single
        Get
            Return Me.sc
        End Get
        Set(ByVal value As Single)
            Me.sc = value
        End Set
    End Property

    Public Property LeftImagePosition() As Single
        Get
            Return Me.pos.X
        End Get
        Set(ByVal value As Single)
            Me.pos.X = value
        End Set
    End Property

    Public Property Position() As PointF
        Get
            Return Me.pos
        End Get
        Set(ByVal value As PointF)
            Me.pos = value
        End Set
    End Property

    Public Property PreviousPosition() As PointF
        Get
            Return Me.old_Pos
        End Get
        Set(ByVal value As PointF)
            Me.old_Pos = value
        End Set
    End Property

    Private ReadOnly Property RealScale() As String
        Get
            If (Not Me.cadImage Is Nothing) Then
                Return String.Format("{0,2:F}%", (((CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)) / Me.cadImage.AbsWidth) * Me.cadImage.MMToPixelX) * 100))
            End If
            Return String.Format("{0}%", Me.ImageScale)
        End Get
    End Property

    Private ReadOnly Property RealScaleDouble() As Double
        Get
            If (Not Me.cadImage Is Nothing) Then
                Return ((CDbl((Me.VisibleAreaSize.Width * Me.ImageScale)) / Me.cadImage.AbsWidth) * Me.cadImage.MMToPixelX)
            End If
            Return Me.ImageScale
        End Get
    End Property

    Public Property StartPoint() As Point
        Get
            Return Me.startPt
        End Get
        Set(ByVal value As Point)
            Me.startPt = value
        End Set
    End Property

    Public Property TopImagePosition() As Single
        Get
            Return Me.pos.Y
        End Get
        Set(ByVal value As Single)
            Me.pos.Y = value
        End Set
    End Property

    Public Property VisibleAreaSize() As SizeF
        Get
            Return Me.visibleArea
        End Get
        Set(ByVal value As SizeF)
            Me.visibleArea = value
        End Set
    End Property


    ' Fields
    Private aboutForm As aboutForm
    Private addEntity As Integer
    Private cadImage As cadImage
    Private cadPictBox As CADPictureBox
    Private clipRectangle As ClipRect
    Private cntrlDown As Boolean
    Private colorDraw As Boolean
    Private components As IContainer
    Private curAddEntityType As CreatorType
    Private curLngInd As Integer
    Private cX As Integer
    Private cY As Integer
    Private detMouseDown As Boolean
    Private dimVisible As Boolean
    Private dlgOpenSerializeFile As OpenFileDialog
    Private dlgSaveSerializeFile As SaveFileDialog
    Private enableSnap As Boolean
    Private endPt As Point
    Private entCreator As EntitiesCreator
    Private Shared fileName As String
    Private Shared ReadOnly fileSettingsName As String = (Application.StartupPath & "\Settings.txt")
    Private floatLicFrm As FloatLicForm
    Private lForm As LayerForm
    Private listItemSelectDel As ListItemSelectEventHandler
    Private lngFile As String
    Private mainMenu As mainMenu
    Private miAbout As MenuItem
    Private miArcsSplit As MenuItem
    Private miBlackBack As MenuItem
    Private miBlackDraw As MenuItem
    Private miCADFiles As MenuItem
    Private miClose As MenuItem
    Private miColorDraw As MenuItem
    Private miCopy As MenuItem
    Private miCopyAsBMP As MenuItem
    Private miCut As MenuItem
    Private miDelete As MenuItem
    Private miDeserializeEntities As MenuItem
    Private miDimShow As MenuItem
    Private miEdit As MenuItem
    Private miEntitiesTree As MenuItem
    Private miExit As MenuItem
    Private miFile As MenuItem
    Private miFit As MenuItem
    Private miFloatLic As MenuItem
    Private miLayersShow As MenuItem
    Private miLng As MenuItem
    Private miOpenFile As MenuItem
    Private miOptions As MenuItem
    Private miPaste As MenuItem
    Private miPrint As MenuItem
    Private miPrintCustom As MenuItem
    Private miPrintPreview As MenuItem
    Private miRedo As MenuItem
    Private miReg As MenuItem
    Private miRegister As MenuItem
    Private miSaveAsDXF As MenuItem
    Private miSaveFile As MenuItem
    Private miScale As MenuItem
    Private miSep1 As MenuItem
    Private miSep2 As MenuItem
    Private miSep3 As MenuItem
    Private miSep4 As MenuItem
    Private miSep5 As MenuItem
    Private miSerializeEntities As MenuItem
    Private miShowLineWeight As MenuItem
    Private miSHXFontsPaths As MenuItem
    Private miTextsShow As MenuItem
    Private miUndo As MenuItem
    Private miView As MenuItem
    Private miWhiteBack As MenuItem
    Private miZoom10 As MenuItem
    Private miZoom100 As MenuItem
    Private miZoom200 As MenuItem
    Private miZoom25 As MenuItem
    Private miZoom400 As MenuItem
    Private miZoom50 As MenuItem
    Private miZoom800 As MenuItem
    Private miZoomIn As MenuItem
    Private miZoomOut As MenuItem
    Private mlng As MultipleLanguage
    Private moveMarker As Boolean
    Private old_Pos As PointF
    Private openFileDlg As OpenFileDialog
    Private pos As PointF
    Private prev_sc As Single
    Private printPrevDlg As PrintPreviewDialog
    Private propGrid As PropertyGrid
    Private prtForm As CADImport.Printing.PrintingForm
    Private rasterSizeForm As SetRasterSizeForm
    Private regFrm As RegForm
    Private saveDXFDlg As SaveFileDialog
    Private saveImgDlg As SaveFileDialog
    Private sbCoord As StatusBarPanel
    Private sbOpen As StatusBarPanel
    Private sbScale As StatusBarPanel
    Private sc As Single
    Private setColorDlg As ColorDialog
    Private settingsLst As SortedList
    Private showLineWeight As Boolean
    Private shxFrm As SHXForm
    Private spltPictBox As Splitter
    Private spProp As Splitter
    Private startPt As Point
    Private stBar As StatusBar
    Private stopSnap As Boolean
    Private svSet As SaveSettings
    Private textVisible As Boolean
    Private tlbAddHatch As ToolBarButton
    Private tlbAddImgEnt As ToolBarButton
    Private tlbAddMText As ToolBarButton
    Private tlbAddSolid As ToolBarButton
    Private tlbBlack As ToolBarButton
    Private tlbCircle As ToolBarButton
    Private tlbCloud As ToolBarButton
    Private tlbDel As ToolBarButton
    Private tlbGetExt As ToolBarButton
    Private tlbLay As ToolBarButton
    Private tlbLine As ToolBarButton
    Private tlbNew As ToolBarButton
    Private tlbOpen As ToolBarButton
    Private tlbOptions As ToolBarButton
    Private tlbPen As ToolBarButton
    Private tlbPoint As ToolBarButton
    Private tlbPoly As ToolBarButton
    Private tlbRect As ToolBarButton
    Private tlbRedo As ToolBarButton
    Private tlbSave As ToolBarButton
    Private tlbShx As ToolBarButton
    Private tlbSnap As ToolBarButton
    Private tlbText As ToolBarButton
    Private tlbTool As ToolBar
    Private tlbUndo As ToolBarButton
    Private tlbWhite As ToolBarButton
    Private tlbZoomIn As ToolBarButton
    Private tlbZoomOut As ToolBarButton
    Private toolBtnImageList As ImageList
    Private trvEntity As TreeView
    Private trvPanel As Panel
    Private useSHXFonts As Boolean
    Private visibleArea As SizeF
End Class

Friend MustInherit Class ApplicationConstants
    ' Methods
    Protected Sub New()
    End Sub


    ' Fields
    Public Shared ReadOnly appconst As String = "Application"
    Public Shared ReadOnly appnamestr As String = "CADImportNet Demo"
    Public Shared ReadOnly backcolorstr As String = "BackgroundColor"
    Public Shared ReadOnly blackstr As String = "BLACK"
    Public Shared ReadOnly blackstr2 As String = "Black"
    Public Shared ReadOnly blocksstr As String = "Blocks"
    Public Shared ReadOnly bmpextstr As String = ".BMP"
    Public Shared ReadOnly colordrawstr As String = "ColorDraw"
    Public Shared ReadOnly colorstr As String = "Color"
    Public Shared ReadOnly datextstr As String = ".dat"
    Public Shared ReadOnly defaultstr As String = "Default"
    Public Shared ReadOnly drawmodestr As String = "drawMode"
    Public Shared ReadOnly dxfextstr As String = ".DXF"
    Public Shared ReadOnly emfextstr As String = ".EMF"
    Public Shared ReadOnly entitiesstr As String = "Entities"
    Public Shared ReadOnly floatingstr As String = "floating"
    Public Shared ReadOnly freezestr As String = "Freeze"
    Public Shared ReadOnly gifextstr As String = ".GIF"
    Public Shared ReadOnly headstr1 As String = "Head1"
    Public Shared ReadOnly headstr2 As String = "Head2"
    Public Shared ReadOnly headstr3 As String = "Head3"
    Public Shared ReadOnly headstr4 As String = "Head4"
    Public Shared ReadOnly hoststr As String = "Host"
    Public Shared ReadOnly installstr As String = "Install"
    Public Shared ReadOnly jpgextstr As String = ".JPG"
    Public Shared ReadOnly languageIDstr As String = "LanguageID"
    Public Shared ReadOnly languagepath As String = "LanguagePath"
    Public Shared ReadOnly languagestr As String = "Language"
    Public Shared ReadOnly layersstr As String = "Layers"
    Public Shared ReadOnly layoutsstr As String = "Layouts"
    Public Shared ReadOnly lngextstr As String = ".lng"
    Public Shared ReadOnly loadfilestr As String = "Loading file..."
    Public Shared ReadOnly ltypesstr As String = "LTypes"
    Public Shared ReadOnly messagestr As String = "If you proceed with this operation, all added objects will be lost. Continue?"
    Public Shared ReadOnly msgBoxDebugCaption As String = "Debug application message"
    Public Shared ReadOnly namestr As String = "Name"
    Public Shared ReadOnly notsupportedextstr As String = "Not supported in current version!"
    Public Shared ReadOnly notsupportedstr As String = "not supported"
    Public Shared ReadOnly pngextstr As String = ".PNG"
    Public Shared ReadOnly portstr As String = "Port"
    Public Shared ReadOnly registerstr As String = "register"
    Public Shared ReadOnly sepstr As String = " - "
    Public Shared ReadOnly sepstr2 As String = " : "
    Public Shared ReadOnly sepstr3 As String = ";"
    Public Shared ReadOnly showentitystr As String = "ShowEntity"
    Public Shared ReadOnly shxpathcnstr As String = "SHXPathCount"
    Public Shared ReadOnly stylesstr As String = "Styles"
    Public Shared ReadOnly tiffextstr As String = ".TIFF"
    Public Shared ReadOnly truestr As String = "TRUE"
    Public Shared ReadOnly typelcstr As String = "Type_license"
    Public Shared ReadOnly visiblestr As String = "Visible"
    Public Shared ReadOnly vportsstr As String = "VPorts"
    Public Shared ReadOnly whitestr As String = "White"
    Public Shared ReadOnly wmfextstr As String = ".WMF"
    Public Shared ReadOnly xrefsstr As String = "XRefs"
End Class
