using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using CADImport.FaceModule;
using CADImport.CADImportForms;


namespace CADImportNetDemos.CADViewerControlDemo
{
	#region Help
	/// <summary>
	/// Represents the main application form in which a <B>CADImportControl</B> is used for viewing CAD files.
	/// </summary>
	#endregion Help
	public class MainForm : System.Windows.Forms.Form
	{				
		private SaveSettings svSet;
		private static SortedList settingsLst;				
		private CADImport.CADImportControls.CADViewerControl cadViewerControl1;		
		private static readonly string fileSettingsName;
		private string lngFile;
		private CADImport.FaceModule.MultipleLanguage mlng;
		private int curLngIndex;
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem miFile;
		private System.Windows.Forms.MenuItem miOpenFile;
		private System.Windows.Forms.MenuItem miOpenFromWeb;
		private System.Windows.Forms.MenuItem miSaveFile;
		private System.Windows.Forms.MenuItem miSaveAsDXF;
		private System.Windows.Forms.MenuItem miPrint;
		private System.Windows.Forms.MenuItem miCustomPrint;
		private System.Windows.Forms.MenuItem miPrintPreview;
		private System.Windows.Forms.MenuItem miClosePicture;
		private System.Windows.Forms.MenuItem miSeparator1;
		private System.Windows.Forms.MenuItem miExit;
		private System.Windows.Forms.MenuItem editMenuItem;
		private System.Windows.Forms.MenuItem miCopyAsBMP;
		private System.Windows.Forms.MenuItem mView;
		private System.Windows.Forms.MenuItem miShowEntityTree;
		private System.Windows.Forms.MenuItem miSeparator2;
		private System.Windows.Forms.MenuItem miZoomIn;
		private System.Windows.Forms.MenuItem miZoomOut;
		private System.Windows.Forms.MenuItem miScale;
		private System.Windows.Forms.MenuItem miZoom10;
		private System.Windows.Forms.MenuItem miZoom25;
		private System.Windows.Forms.MenuItem miZoom50;
		private System.Windows.Forms.MenuItem miZoom100;
		private System.Windows.Forms.MenuItem miZoom200;
		private System.Windows.Forms.MenuItem miZoom400;
		private System.Windows.Forms.MenuItem miZoom800;
		private System.Windows.Forms.MenuItem miFitToWindow;
		private System.Windows.Forms.MenuItem miSeparator3;
		private System.Windows.Forms.MenuItem miShowShxForm;
		private System.Windows.Forms.MenuItem miShowOptionsForm;
		private System.Windows.Forms.MenuItem cADFilesMenuItem;
		private System.Windows.Forms.MenuItem miDrawNormalColor;
		private System.Windows.Forms.MenuItem miDrawBlackColor;
		private System.Windows.Forms.MenuItem miWhiteBackground;
		private System.Windows.Forms.MenuItem miBlackBackground;
		private System.Windows.Forms.MenuItem miChangeBackgroundColor;
		private System.Windows.Forms.MenuItem miSeparator4;
		private System.Windows.Forms.MenuItem miShowLineWeight;
		private System.Windows.Forms.MenuItem miArcsSplit;
		private System.Windows.Forms.MenuItem miDimShow;
		private System.Windows.Forms.MenuItem miTextsShow;
		private System.Windows.Forms.MenuItem miSeparator5;
		private System.Windows.Forms.MenuItem miLayersShow;
		private System.Windows.Forms.MenuItem mi3DViews;
		private System.Windows.Forms.MenuItem miInitialView;
		private System.Windows.Forms.MenuItem miTopView;
		private System.Windows.Forms.MenuItem miBottomView;
		private System.Windows.Forms.MenuItem miLeftView;
		private System.Windows.Forms.MenuItem miRightView;
		private System.Windows.Forms.MenuItem miFrontView;
		private System.Windows.Forms.MenuItem miBackView;
		private System.Windows.Forms.MenuItem miSWIsometricView;
		private System.Windows.Forms.MenuItem miSEIsometricView;
		private System.Windows.Forms.MenuItem miNEIsometricView;
		private System.Windows.Forms.MenuItem miNWIsometricView;
		private System.Windows.Forms.MenuItem miEnable3DOrbit;
		private System.Windows.Forms.MenuItem helpMenuItem;
		private System.Windows.Forms.MenuItem miLanguages;
		private System.Windows.Forms.MenuItem miRegistration;
		private System.Windows.Forms.MenuItem miFloatLic;
		private System.Windows.Forms.MenuItem miAbout;
		private System.Windows.Forms.SaveFileDialog saveDXFDlg;			
	
		static MainForm()
		{		
			fileSettingsName = Application.StartupPath + @"\Settings.txt";
		}

		#region Help
		/// <summary>
		/// Initializes a new instance of the <see cref="MainForm">MainForm</see> class.
		/// </summary>
		#endregion Help
		public MainForm()
		{
			InitializeComponent();			
			InitParams();
		}
		private void InitParams()
		{
			#region protect
#if ((! floatprotect) && protect)
				this.miFloatLic.Enabled = false;
#endif
			#endregion									
			svSet = new SaveSettings(fileSettingsName);
			settingsLst = svSet.LoadOptions();			
			lngFile = ApplicationConstants.defaultstr;			
			curLngIndex = 0;						
			this.InitLng();
			if(settingsLst == null)
				CreateNewSettingsList();
			else
				SetSettings();					
			ReloadLNG();
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
			SetAllFormsSettings();
			this.cadViewerControl1.ChangeTextShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadViewerControl1.ChangeDimensionShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadViewerControl1.ChangeLineWeightShow += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);
			this.cadViewerControl1.ChangeBackgroundColor += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);			
			this.cadViewerControl1.OptionsForm.ChangeBackgroundColor += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);			
			this.cadViewerControl1.OptionsForm.ChangeDrawingColors += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);								
			this.cadViewerControl1.OptionsForm.ChangeEntityPanelVisible += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeControlState);								
			this.cadViewerControl1.OptionsForm.SettingsList = settingsLst;						
		}

		private void ChangeControlState(bool val)
		{
			this.miTextsShow.Checked = this.cadViewerControl1.TextVisible;
			this.miDimShow.Checked = this.cadViewerControl1.DimensionVisible;
			this.miShowLineWeight.Checked = this.cadViewerControl1.ShowLineWeight;
			bool colorblack = this.cadViewerControl1.Image.BackgroundColor.Equals(Color.Black);
			this.miBlackBackground.Checked = colorblack;
			this.miWhiteBackground.Checked = ! colorblack;
			this.miShowEntityTree.Checked = this.cadViewerControl1.EntityTreeVisible;
			this.miDrawNormalColor.Checked = this.cadViewerControl1.ColorDraw;
			this.miDrawBlackColor.Checked = ! this.cadViewerControl1.ColorDraw;
		}

		private void InitLng()
		{
			mlng = new MultipleLanguage(this.GetType());			
			if(this.mainMenu != null)
				mlng.SaveNameMenuItem(this.mainMenu.MenuItems);
			if(this.ContextMenu != null)
				mlng.SaveNameMenuItem(this.ContextMenu.MenuItems);
			mlng.SaveNameNoNameElement(this.Controls);			
		}

		private void SetAllFormsSettings()
		{	
			SetAllFormsLanguageSettings();	
			this.cadViewerControl1.OptionsForm.SettingsList = settingsLst;								
			this.cadViewerControl1.OptionsForm.ChangeLngPath += new CADImport.CADImportForms.ChangeLngPathEventHandler(ReloadLNG);
			this.cadViewerControl1.OptionsForm.ChangeLanguage += new CADImport.CADImportForms.ChangeLanguageEventHandler(ChangeLanguage);						
		}		

		internal void ReloadLNG(string val)
		{
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.Path = val;
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
		}

		private void SetAllFormsLanguageSettings()
		{
			this.cadViewerControl1.OptionsForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.OptionsForm.LngFileName = lngFile;			
			this.cadViewerControl1.AboutForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.AboutForm.LngFileName = lngFile;
			#region FloatingLic
#if floatprotect
			this.cadViewerControl1.FloatingRegistrationForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.FloatingRegistrationForm.LngFileName = lngFile;
#endif
			#endregion
			this.cadViewerControl1.LayerForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.LayerForm.LngFileName = lngFile;
			this.cadViewerControl1.PrintingForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.PrintingForm.LngFileName = lngFile;
			this.cadViewerControl1.RegistrationForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.RegistrationForm.LngFileName = lngFile;
			this.cadViewerControl1.RasterSizeForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.RasterSizeForm.LngFileName = lngFile;
			this.cadViewerControl1.SHXForm.MultipleLanguagesPath = mlng.Path;
			this.cadViewerControl1.SHXForm.LngFileName = lngFile;
		}
		
		private void InitSettings()
		{			
			svSet = new SaveSettings(fileSettingsName);
			settingsLst = svSet.LoadOptions();
			if(settingsLst != null)
			{
				string key = ApplicationConstants.languagepath;
				if(settingsLst.ContainsKey(key))
					this.mlng.Path = Convert.ToString(settingsLst[key]);
			} 
			else			
				this.mlng.Path = @".\Languages";			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(settingsLst == null)
				CreateNewSettingsList();
			else
				SetSettings();
		}

		private void LanguageSelect_Click(object sender, System.EventArgs e)
		{
			if(!(sender is MenuItem)) 
				return;
			MenuItem mn = (sender as MenuItem);
			curLngIndex = (byte)mn.Index;
			lngFile = mn.Text + ApplicationConstants.lngextstr; 
			SetAllFormsLanguageSettings();
			SetLNG();
			this.cadViewerControl1.ChangeControlState();
		}

		#region Help
#if RUSHELP
		/// <summary>
		///     
		/// </summary>
		/// <param name="val"> </param>
		/// <param name="index">     </param>
#else
		/// <summary>
		/// Sets specified linguage for the application
		/// </summary>
		/// <param name="val">A language to set</param>
		/// <param name="index">An index of a language in the languages list</param>
#endif
		#endregion
		public void ChangeLanguage(string val, int index)
		{
			curLngIndex = index;
			lngFile = val + ApplicationConstants.lngextstr; 
			SetAllFormsLanguageSettings();
			SetLNG();
			this.cadViewerControl1.ChangeControlState();
		}	

		private void SetLNG()
		{
			mlng.LoadLNG(lngFile);
			mlng.RestoreLanguage(this.Controls, this.Menu);
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			this.Text = ApplicationConstants.appnamestr;
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
		}

		internal void SetSettings()
		{
			if(settingsLst == null)
				return;
			string tmp; 
			int cn = 0;
			//Language path
			string key = ApplicationConstants.languagepath;
			if(settingsLst.ContainsKey(key))
				this.mlng.Path = Convert.ToString(settingsLst[key]);
			//Language
			key = ApplicationConstants.languagestr;
			if(settingsLst.ContainsKey(key))
				lngFile = (string)settingsLst[key];
			mlng.LoadLNG(lngFile);
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
			//Language ID
			key = ApplicationConstants.languageIDstr;
			if(settingsLst.ContainsKey(key))
				this.curLngIndex = Convert.ToByte(settingsLst[key]);
			//BackgroundColor
			key = ApplicationConstants.backcolorstr;
			tmp = ApplicationConstants.blackstr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.blackstr)
				this.cadViewerControl1.Black_Click();
			else 
				this.cadViewerControl1.White_Click();
			//Show entity panel
			key = ApplicationConstants.showentitystr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.cadViewerControl1.EntityTreeVisible = true;
			else
				this.cadViewerControl1.EntityTreeVisible = false;
			//Color drawing
			key = ApplicationConstants.drawmodestr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.cadViewerControl1.ColorDraw = true;
			else 
				this.cadViewerControl1.ColorDraw = false;
			//SHXPathCount
			key = ApplicationConstants.shxpathcnstr;
			if(settingsLst.ContainsKey(key))
				cn = Convert.ToInt32(settingsLst[key]);
			//SHXPaths
			for(int i = 0; i < cn; i++)
			{
				key = string.Format("SHXPath_{0}", (i + 1));
				if(settingsLst.ContainsKey(key))
					this.cadViewerControl1.SHXForm.AddPath(Convert.ToString(settingsLst[key]));
			}
			//First start
			key = ApplicationConstants.installstr;
			if(settingsLst.ContainsKey(key))
			{
				if(CADImport.CADConst.SearchSHXPaths)
				{
					this.cadViewerControl1.SHXForm.lstDir.Items.Clear();
					this.cadViewerControl1.SHXForm.lstPath.Clear();
					ArrayList vPaths = new ArrayList();
					CADImport.CADConst.FindAutoCADSHXPaths(vPaths);
					for(int i = 0; i < vPaths.Count; i++)
					{
						tmp = (string)vPaths[i];
						this.cadViewerControl1.SHXForm.lstDir.Items.Add(tmp);
						this.cadViewerControl1.SHXForm.lstPath.Add(tmp, string.Empty);
						CADImport.CADConst.SHXSearchPaths += CADImport.CADConst.SHXSearchPaths + tmp + ApplicationConstants.sepstr3;
					}
				}
			}
			#region protect
#if protect			
			key = ApplicationConstants.typelcstr;
			if(settingsLst.ContainsKey(key))
			{
				tmp = (string)settingsLst[key];
#if floatprotect
				if(tmp == ApplicationConstants.floatingstr)
				{
					CADImport.Protection.LicenseType = CADImport.LicenseType.Floating;
					key = ApplicationConstants.hoststr;
					if(settingsLst.ContainsKey(key))
					{
						this.cadViewerControl1.FloatingRegistrationForm.Host = (string)settingsLst[key];
					}
					key = ApplicationConstants.portstr;
					if(settingsLst.ContainsKey(key))
					{
						this.cadViewerControl1.FloatingRegistrationForm.Port = Convert.ToInt32(settingsLst[key]);
					}
					key = ApplicationConstants.appconst;
					if(settingsLst.ContainsKey(key))
					{
						this.cadViewerControl1.FloatingRegistrationForm.App = (string)settingsLst[key];
					}
				}
				else
				{
					CADImport.Protection.LicenseType = CADImport.LicenseType.Register;
				}
#else
					CADImport.Protection.LicenseType = LicenseType.Register;
#endif
			}
#endif
			#endregion
		}		

		private void SelectLanguage()
		{
			for(int i = 0; i < this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count; i++)
				if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[i].Text == "English")
				{
					this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[i].Checked = true;
					this.curLngIndex = i;
					break;
				}
		}		

		internal void ReloadLNG()
		{			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
		}

		#region Help
		/// <summary>
		/// Cleans up any resources being used.
		/// </summary>
		/// <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
		///</param>
		#endregion Help
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.saveDXFDlg = new System.Windows.Forms.SaveFileDialog();
			this.cadViewerControl1 = new CADImport.CADImportControls.CADViewerControl();
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.miFile = new System.Windows.Forms.MenuItem();
			this.miOpenFile = new System.Windows.Forms.MenuItem();
			this.miOpenFromWeb = new System.Windows.Forms.MenuItem();
			this.miSaveFile = new System.Windows.Forms.MenuItem();
			this.miSaveAsDXF = new System.Windows.Forms.MenuItem();
			this.miPrint = new System.Windows.Forms.MenuItem();
			this.miCustomPrint = new System.Windows.Forms.MenuItem();
			this.miPrintPreview = new System.Windows.Forms.MenuItem();
			this.miClosePicture = new System.Windows.Forms.MenuItem();
			this.miSeparator1 = new System.Windows.Forms.MenuItem();
			this.miExit = new System.Windows.Forms.MenuItem();
			this.editMenuItem = new System.Windows.Forms.MenuItem();
			this.miCopyAsBMP = new System.Windows.Forms.MenuItem();
			this.mView = new System.Windows.Forms.MenuItem();
			this.miShowEntityTree = new System.Windows.Forms.MenuItem();
			this.miSeparator2 = new System.Windows.Forms.MenuItem();
			this.miZoomIn = new System.Windows.Forms.MenuItem();
			this.miZoomOut = new System.Windows.Forms.MenuItem();
			this.miScale = new System.Windows.Forms.MenuItem();
			this.miZoom10 = new System.Windows.Forms.MenuItem();
			this.miZoom25 = new System.Windows.Forms.MenuItem();
			this.miZoom50 = new System.Windows.Forms.MenuItem();
			this.miZoom100 = new System.Windows.Forms.MenuItem();
			this.miZoom200 = new System.Windows.Forms.MenuItem();
			this.miZoom400 = new System.Windows.Forms.MenuItem();
			this.miZoom800 = new System.Windows.Forms.MenuItem();
			this.miFitToWindow = new System.Windows.Forms.MenuItem();
			this.miSeparator3 = new System.Windows.Forms.MenuItem();
			this.miShowShxForm = new System.Windows.Forms.MenuItem();
			this.miShowOptionsForm = new System.Windows.Forms.MenuItem();
			this.cADFilesMenuItem = new System.Windows.Forms.MenuItem();
			this.miDrawNormalColor = new System.Windows.Forms.MenuItem();
			this.miDrawBlackColor = new System.Windows.Forms.MenuItem();
			this.miWhiteBackground = new System.Windows.Forms.MenuItem();
			this.miBlackBackground = new System.Windows.Forms.MenuItem();
			this.miChangeBackgroundColor = new System.Windows.Forms.MenuItem();
			this.miSeparator4 = new System.Windows.Forms.MenuItem();
			this.miShowLineWeight = new System.Windows.Forms.MenuItem();
			this.miArcsSplit = new System.Windows.Forms.MenuItem();
			this.miDimShow = new System.Windows.Forms.MenuItem();
			this.miTextsShow = new System.Windows.Forms.MenuItem();
			this.miSeparator5 = new System.Windows.Forms.MenuItem();
			this.miLayersShow = new System.Windows.Forms.MenuItem();
			this.mi3DViews = new System.Windows.Forms.MenuItem();
			this.miInitialView = new System.Windows.Forms.MenuItem();
			this.miTopView = new System.Windows.Forms.MenuItem();
			this.miBottomView = new System.Windows.Forms.MenuItem();
			this.miLeftView = new System.Windows.Forms.MenuItem();
			this.miRightView = new System.Windows.Forms.MenuItem();
			this.miFrontView = new System.Windows.Forms.MenuItem();
			this.miBackView = new System.Windows.Forms.MenuItem();
			this.miSWIsometricView = new System.Windows.Forms.MenuItem();
			this.miSEIsometricView = new System.Windows.Forms.MenuItem();
			this.miNEIsometricView = new System.Windows.Forms.MenuItem();
			this.miNWIsometricView = new System.Windows.Forms.MenuItem();
			this.miEnable3DOrbit = new System.Windows.Forms.MenuItem();
			this.helpMenuItem = new System.Windows.Forms.MenuItem();
			this.miLanguages = new System.Windows.Forms.MenuItem();
			this.miRegistration = new System.Windows.Forms.MenuItem();
			this.miFloatLic = new System.Windows.Forms.MenuItem();
			this.miAbout = new System.Windows.Forms.MenuItem();
			this.SuspendLayout();
			// 
			// saveDXFDlg
			// 
			this.saveDXFDlg.DefaultExt = "*.dxf";
			this.saveDXFDlg.Filter = "*.dxf|*.dxf";
			// 
			// cadViewerControl1
			// 
			this.cadViewerControl1.ColorDraw = true;
			this.cadViewerControl1.DimensionVisible = true;
			this.cadViewerControl1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.cadViewerControl1.ColorDraw = true;
			this.cadViewerControl1.EntityPropertyGridVisible = true;
			this.cadViewerControl1.EntityTreeVisible = true;
			this.cadViewerControl1.Image = null;
			this.cadViewerControl1.ImagePreviousScale = 1F;
			this.cadViewerControl1.ImageScale = 1F;
			this.cadViewerControl1.InFileName = "";
			this.cadViewerControl1.LayoutsPanelVisible = true;
			this.cadViewerControl1.LeftImagePosition = 0F;
			this.cadViewerControl1.Location = new System.Drawing.Point(0, 0);
			this.cadViewerControl1.Name = "cadViewerControl1";
			this.cadViewerControl1.OutFileName = "";
			this.cadViewerControl1.Position = ((System.Drawing.PointF)(resources.GetObject("cadViewerControl1.Position")));
			this.cadViewerControl1.PreviousPosition = ((System.Drawing.PointF)(resources.GetObject("cadViewerControl1.PreviousPosition")));
			this.cadViewerControl1.PropertyEntityPanelVisible = true;
			this.cadViewerControl1.ShowLineWeight = false;
			this.cadViewerControl1.Size = new System.Drawing.Size(720, 403);
			this.cadViewerControl1.StatusBarPanelVisible = true;
			this.cadViewerControl1.TabIndex = 0;
			this.cadViewerControl1.TextVisible = true;
			this.cadViewerControl1.ToolsPanelVisible = true;
			this.cadViewerControl1.TopImagePosition = 0F;
			this.cadViewerControl1.VisibleAreaSize = ((System.Drawing.SizeF)(resources.GetObject("cadViewerControl1.VisibleAreaSize")));
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.miFile,
																					 this.editMenuItem,
																					 this.mView,
																					 this.cADFilesMenuItem,
																					 this.helpMenuItem});
			// 
			// miFile
			// 
			this.miFile.Index = 0;
			this.miFile.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				   this.miOpenFile,
																				   this.miOpenFromWeb,
																				   this.miSaveFile,
																				   this.miSaveAsDXF,
																				   this.miPrint,
																				   this.miCustomPrint,
																				   this.miPrintPreview,
																				   this.miClosePicture,
																				   this.miSeparator1,
																				   this.miExit});
			this.miFile.Text = "&File";
			// 
			// miOpenFile
			// 
			this.miOpenFile.Index = 0;
			this.miOpenFile.Shortcut = System.Windows.Forms.Shortcut.CtrlO;
			this.miOpenFile.Text = "Open Picture...";
			this.miOpenFile.Click += new System.EventHandler(this.miOpenFile_Click);
			// 
			// miOpenFromWeb
			// 
			this.miOpenFromWeb.Index = 1;
			this.miOpenFromWeb.Text = "Open Picture from Web...";
			this.miOpenFromWeb.Click += new System.EventHandler(this.miOpenFromWeb_Click);
			// 
			// miSaveFile
			// 
			this.miSaveFile.Enabled = false;
			this.miSaveFile.Index = 2;
			this.miSaveFile.Text = "Save Picture...";
			this.miSaveFile.Click += new System.EventHandler(this.miSaveFile_Click);
			// 
			// miSaveAsDXF
			// 
			this.miSaveAsDXF.Enabled = false;
			this.miSaveAsDXF.Index = 3;
			this.miSaveAsDXF.Text = "Save as DXF...";
			this.miSaveAsDXF.Click += new System.EventHandler(this.miSaveAsDXF_Click);
			// 
			// miPrint
			// 
			this.miPrint.Enabled = false;
			this.miPrint.Index = 4;
			this.miPrint.Text = "Print ";
			this.miPrint.Click += new System.EventHandler(this.miPrint_Click);
			// 
			// miCustomPrint
			// 
			this.miCustomPrint.Enabled = false;
			this.miCustomPrint.Index = 5;
			this.miCustomPrint.Shortcut = System.Windows.Forms.Shortcut.CtrlP;
			this.miCustomPrint.Text = "Custom Print Preview...";
			this.miCustomPrint.Click += new System.EventHandler(this.miCustomPrint_Click);
			// 
			// miPrintPreview
			// 
			this.miPrintPreview.Enabled = false;
			this.miPrintPreview.Index = 6;
			this.miPrintPreview.Text = "Print Preview...";
			this.miPrintPreview.Click += new System.EventHandler(this.miPrintPreview_Click);
			// 
			// miClosePicture
			// 
			this.miClosePicture.Enabled = false;
			this.miClosePicture.Index = 7;
			this.miClosePicture.Text = "Close Picture";
			this.miClosePicture.Click += new System.EventHandler(this.miClosePicture_Click);
			// 
			// miSeparator1
			// 
			this.miSeparator1.Index = 8;
			this.miSeparator1.Text = "-";
			// 
			// miExit
			// 
			this.miExit.Index = 9;
			this.miExit.Text = "Close";
			this.miExit.Click += new System.EventHandler(this.miExit_Click);
			// 
			// editMenuItem
			// 
			this.editMenuItem.Index = 1;
			this.editMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.miCopyAsBMP});
			this.editMenuItem.Text = "&Edit";
			// 
			// miCopyAsBMP
			// 
			this.miCopyAsBMP.Enabled = false;
			this.miCopyAsBMP.Index = 0;
			this.miCopyAsBMP.Text = "Copy as BMP";
			this.miCopyAsBMP.Click += new System.EventHandler(this.miCopy_Click);
			// 
			// mView
			// 
			this.mView.Index = 2;
			this.mView.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				  this.miShowEntityTree,
																				  this.miSeparator2,
																				  this.miZoomIn,
																				  this.miZoomOut,
																				  this.miScale,
																				  this.miFitToWindow,
																				  this.miSeparator3,
																				  this.miShowShxForm,
																				  this.miShowOptionsForm});
			this.mView.Text = "&View";
			// 
			// miShowEntityTree
			// 
			this.miShowEntityTree.Checked = true;
			this.miShowEntityTree.Index = 0;
			this.miShowEntityTree.Text = "Show entities panel";
			this.miShowEntityTree.Click += new System.EventHandler(this.miEntities_Click);
			// 
			// miSeparator2
			// 
			this.miSeparator2.Index = 1;
			this.miSeparator2.Text = "-";
			// 
			// miZoomIn
			// 
			this.miZoomIn.Enabled = false;
			this.miZoomIn.Index = 2;
			this.miZoomIn.Text = "Zoom In (+)";
			this.miZoomIn.Click += new System.EventHandler(this.miZoomIn_Click);
			// 
			// miZoomOut
			// 
			this.miZoomOut.Enabled = false;
			this.miZoomOut.Index = 3;
			this.miZoomOut.Text = "Zoom Out (-)";
			this.miZoomOut.Click += new System.EventHandler(this.miZoomOut_Click);
			// 
			// miScale
			// 
			this.miScale.Enabled = false;
			this.miScale.Index = 4;
			this.miScale.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					this.miZoom10,
																					this.miZoom25,
																					this.miZoom50,
																					this.miZoom100,
																					this.miZoom200,
																					this.miZoom400,
																					this.miZoom800});
			this.miScale.Text = "Scale";
			// 
			// miZoom10
			// 
			this.miZoom10.Index = 0;
			this.miZoom10.Text = "10%";
			this.miZoom10.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom25
			// 
			this.miZoom25.Index = 1;
			this.miZoom25.Text = "25%";
			this.miZoom25.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom50
			// 
			this.miZoom50.Index = 2;
			this.miZoom50.Text = "50%";
			this.miZoom50.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom100
			// 
			this.miZoom100.Index = 3;
			this.miZoom100.Text = "100%";
			this.miZoom100.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom200
			// 
			this.miZoom200.Index = 4;
			this.miZoom200.Text = "200%";
			this.miZoom200.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom400
			// 
			this.miZoom400.Index = 5;
			this.miZoom400.Text = "400%";
			this.miZoom400.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miZoom800
			// 
			this.miZoom800.Index = 6;
			this.miZoom800.Text = "800%";
			this.miZoom800.Click += new System.EventHandler(this.miScale_Click);
			// 
			// miFitToWindow
			// 
			this.miFitToWindow.Enabled = false;
			this.miFitToWindow.Index = 5;
			this.miFitToWindow.Text = "Fit drawing to window";
			this.miFitToWindow.Click += new System.EventHandler(this.miFit_Click);
			// 
			// miSeparator3
			// 
			this.miSeparator3.Index = 6;
			this.miSeparator3.Text = "-";
			// 
			// miShowShxForm
			// 
			this.miShowShxForm.Index = 7;
			this.miShowShxForm.Text = "SHX Fonts";
			this.miShowShxForm.Click += new System.EventHandler(this.miSHXFonts_Click);
			// 
			// miShowOptionsForm
			// 
			this.miShowOptionsForm.Index = 8;
			this.miShowOptionsForm.Text = "Options";
			this.miShowOptionsForm.Click += new System.EventHandler(this.miOptions_Click);
			// 
			// cADFilesMenuItem
			// 
			this.cADFilesMenuItem.Index = 3;
			this.cADFilesMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																							 this.miDrawNormalColor,
																							 this.miDrawBlackColor,
																							 this.miWhiteBackground,
																							 this.miBlackBackground,
																							 this.miChangeBackgroundColor,
																							 this.miSeparator4,
																							 this.miShowLineWeight,
																							 this.miArcsSplit,
																							 this.miDimShow,
																							 this.miTextsShow,
																							 this.miSeparator5,
																							 this.miLayersShow,
																							 this.mi3DViews,
																							 this.miEnable3DOrbit});
			this.cADFilesMenuItem.Text = "&CAD files";
			// 
			// miDrawNormalColor
			// 
			this.miDrawNormalColor.Checked = true;
			this.miDrawNormalColor.Enabled = false;
			this.miDrawNormalColor.Index = 0;
			this.miDrawNormalColor.RadioCheck = true;
			this.miDrawNormalColor.Text = "Color drawing";
			this.miDrawNormalColor.Click += new System.EventHandler(this.miColor_Click);
			// 
			// miDrawBlackColor
			// 
			this.miDrawBlackColor.Enabled = false;
			this.miDrawBlackColor.Index = 1;
			this.miDrawBlackColor.RadioCheck = true;
			this.miDrawBlackColor.Text = "Black drawing";
			this.miDrawBlackColor.Click += new System.EventHandler(this.miBlack_Click);
			// 
			// miWhiteBackground
			// 
			this.miWhiteBackground.Enabled = false;
			this.miWhiteBackground.Index = 2;
			this.miWhiteBackground.RadioCheck = true;
			this.miWhiteBackground.Text = "White Background";
			this.miWhiteBackground.Click += new System.EventHandler(this.miWhiteBack_Click);
			// 
			// miBlackBackground
			// 
			this.miBlackBackground.Enabled = false;
			this.miBlackBackground.Index = 3;
			this.miBlackBackground.RadioCheck = true;
			this.miBlackBackground.Text = "Black Background";
			this.miBlackBackground.Click += new System.EventHandler(this.miBlackBack_Click);
			// 
			// miChangeBackgroundColor
			// 
			this.miChangeBackgroundColor.Enabled = false;
			this.miChangeBackgroundColor.Index = 4;
			this.miChangeBackgroundColor.Text = "Change Background Color";
			this.miChangeBackgroundColor.Click += new System.EventHandler(this.miChangeBack_Click);
			// 
			// miSeparator4
			// 
			this.miSeparator4.Index = 5;
			this.miSeparator4.Text = "-";
			// 
			// miShowLineWeight
			// 
			this.miShowLineWeight.Enabled = false;
			this.miShowLineWeight.Index = 6;
			this.miShowLineWeight.Text = "Show Lineweight";
			this.miShowLineWeight.Click += new System.EventHandler(this.miShowLineWight_Click);
			// 
			// miArcsSplit
			// 
			this.miArcsSplit.Checked = true;
			this.miArcsSplit.Enabled = false;
			this.miArcsSplit.Index = 7;
			this.miArcsSplit.Text = "Arcs Splitted";
			this.miArcsSplit.Click += new System.EventHandler(this.miArcsSplit_Click);
			// 
			// miDimShow
			// 
			this.miDimShow.Checked = true;
			this.miDimShow.Enabled = false;
			this.miDimShow.Index = 8;
			this.miDimShow.Text = "Dimensions Show";
			this.miDimShow.Click += new System.EventHandler(this.miDimShow_Click);
			// 
			// miTextsShow
			// 
			this.miTextsShow.Checked = true;
			this.miTextsShow.Enabled = false;
			this.miTextsShow.Index = 9;
			this.miTextsShow.Text = "Texts Show";
			this.miTextsShow.Click += new System.EventHandler(this.miTextsShow_Click);
			// 
			// miSeparator5
			// 
			this.miSeparator5.Index = 10;
			this.miSeparator5.Text = "-";
			// 
			// miLayersShow
			// 
			this.miLayersShow.Enabled = false;
			this.miLayersShow.Index = 11;
			this.miLayersShow.Text = "Show Layers";
			this.miLayersShow.Click += new System.EventHandler(this.miLayersShow_Click);
			// 
			// mi3DViews
			// 
			this.mi3DViews.Enabled = false;
			this.mi3DViews.Index = 12;
			this.mi3DViews.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.miInitialView,
																					  this.miTopView,
																					  this.miBottomView,
																					  this.miLeftView,
																					  this.miRightView,
																					  this.miFrontView,
																					  this.miBackView,
																					  this.miSWIsometricView,
																					  this.miSEIsometricView,
																					  this.miNEIsometricView,
																					  this.miNWIsometricView});
			this.mi3DViews.Text = "3D &Views";
			// 
			// miInitialView
			// 
			this.miInitialView.Index = 0;
			this.miInitialView.Text = "Initial View";
			this.miInitialView.Click += new System.EventHandler(this.miInitialView_Click);
			// 
			// miTopView
			// 
			this.miTopView.Index = 1;
			this.miTopView.Text = "Top View";
			this.miTopView.Click += new System.EventHandler(this.miTopView_Click);
			// 
			// miBottomView
			// 
			this.miBottomView.Index = 2;
			this.miBottomView.Text = "Bottom View";
			this.miBottomView.Click += new System.EventHandler(this.miBottomView_Click);
			// 
			// miLeftView
			// 
			this.miLeftView.Index = 3;
			this.miLeftView.Text = "Left View";
			this.miLeftView.Click += new System.EventHandler(this.miLeftView_Click);
			// 
			// miRightView
			// 
			this.miRightView.Index = 4;
			this.miRightView.Text = "Right View";
			this.miRightView.Click += new System.EventHandler(this.miRightView_Click);
			// 
			// miFrontView
			// 
			this.miFrontView.Index = 5;
			this.miFrontView.Text = "Front View";
			this.miFrontView.Click += new System.EventHandler(this.miFrontView_Click);
			// 
			// miBackView
			// 
			this.miBackView.Index = 6;
			this.miBackView.Text = "Back View";
			this.miBackView.Click += new System.EventHandler(this.miBackView_Click);
			// 
			// miSWIsometricView
			// 
			this.miSWIsometricView.Index = 7;
			this.miSWIsometricView.Text = "SW Isometric";
			this.miSWIsometricView.Click += new System.EventHandler(this.miSWIsometricView_Click);
			// 
			// miSEIsometricView
			// 
			this.miSEIsometricView.Index = 8;
			this.miSEIsometricView.Text = "SE Isometic";
			this.miSEIsometricView.Click += new System.EventHandler(this.miSEIsometricView_Click);
			// 
			// miNEIsometricView
			// 
			this.miNEIsometricView.Index = 9;
			this.miNEIsometricView.Text = "NE Isometric";
			this.miNEIsometricView.Click += new System.EventHandler(this.miNEIsometricView_Click);
			// 
			// miNWIsometricView
			// 
			this.miNWIsometricView.Index = 10;
			this.miNWIsometricView.Text = "NW Isometric";
			this.miNWIsometricView.Click += new System.EventHandler(this.miNWIsometricView_Click);
			// 
			// miEnable3DOrbit
			// 
			this.miEnable3DOrbit.Enabled = false;
			this.miEnable3DOrbit.Index = 13;
			this.miEnable3DOrbit.Text = "3D Orbit";
			this.miEnable3DOrbit.Click += new System.EventHandler(this.miEnable3DOrbit_Click);
			// 
			// helpMenuItem
			// 
			this.helpMenuItem.Index = 4;
			this.helpMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.miLanguages,
																						 this.miRegistration,
																						 this.miFloatLic,
																						 this.miAbout});
			this.helpMenuItem.Text = "&?";
			// 
			// miLanguages
			// 
			this.miLanguages.Index = 0;
			this.miLanguages.Text = "Language";
			// 
			// miRegistration
			// 
			this.miRegistration.Index = 1;
			this.miRegistration.Text = "Register ";
			this.miRegistration.Click += new System.EventHandler(this.miRegister_Click);
			// 
			// miFloatLic
			// 
			this.miFloatLic.Index = 2;
			this.miFloatLic.Text = "Floating License Registration...";
			this.miFloatLic.Click += new System.EventHandler(this.miFloatLic_Click);
			// 
			// miAbout
			// 
			this.miAbout.Index = 3;
			this.miAbout.Text = "About...";
			this.miAbout.Click += new System.EventHandler(this.miAbout_Click);
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(720, 403);
			this.Controls.Add(this.cadViewerControl1);
			this.Menu = this.mainMenu;
			this.Name = "MainForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Viewer";
			this.WindowState = System.Windows.Forms.FormWindowState.Maximized;
			this.Closing += new System.ComponentModel.CancelEventHandler(this.MainForm_Closing);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.Closed += new System.EventHandler(this.MainForm_Closed);
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main() 
		{
			Application.EnableVisualStyles();
			Application.DoEvents();			
			Application.ThreadException += new System.Threading.ThreadExceptionEventHandler(DoExceptionWorking);
			Application.Run(new MainForm());
		}		

		private static void DoExceptionWorking(object sender, System.Threading.ThreadExceptionEventArgs args)
		{				
			CADImport.CADConst.SendExceptionReport(args.Exception);
		}

		private void menuItemAbout_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.AboutForm.ShowDialog();
		}

		private void miScale_Click(object sender, System.EventArgs e)
		{
			if(cadViewerControl1.Image == null) 
				return;
			float i = cadViewerControl1.ImageScale;
			switch((sender as MenuItem).Index)
			{
				case 0:
					i = 0.1f;
					break;
				case 1:
					i = 0.25f;
					break;
				case 2:
					i = 0.5f;
					break;
				case 3:
					i = 1.0f;
					break;
				case 4:
					i = 2.0f;
					break;
				case 5:
					i = 4.0f;
					break;
				case 6:
					i = 8.0f;
					break;
			}
			cadViewerControl1.ResetScaling();
			cadViewerControl1.ImageScale = i;
			cadViewerControl1.InvalidateImage();
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{
			#region protect
			#if protect
			this.cadViewerControl1.Register();
			#endif
			#endregion protect
			EnableButton(true);
		}

		#region Help
		/// <summary>
		/// Enables or disables buttons of the toolbar and menu items of the main menu.
		/// </summary>
		/// <param name="aVal"><b>true</b> if to enable the buttons and menu items; <b>false</b> if to disable them.</param>
		/// <remarks>The buttons and menu items are enabled after loading a CAD file and become disabled after closing the file.</remarks>
		#endregion Help
		public void EnableButton(bool aVal)
		{			
			miScale.Enabled = aVal;
			miSaveFile.Enabled = aVal;
			miCopyAsBMP.Enabled = aVal;
			miZoomIn.Enabled = aVal;
			miZoomOut.Enabled = aVal;
			miFitToWindow.Enabled = aVal;
			miDrawNormalColor.Enabled = aVal;
			miDrawBlackColor.Enabled = aVal;
			miWhiteBackground.Enabled = aVal;
			miBlackBackground.Enabled = aVal;
			miChangeBackgroundColor.Enabled = aVal;
			miShowLineWeight.Enabled = aVal;
			miArcsSplit.Enabled = aVal;
			miDimShow.Enabled = aVal;
			miTextsShow.Enabled = aVal;
			miLayersShow.Enabled = aVal;
			mi3DViews.Enabled = aVal;
			miEnable3DOrbit.Enabled = aVal;
			miClosePicture.Enabled = aVal;
			miPrint.Enabled = aVal;
			miPrintPreview.Enabled = aVal;
			miCustomPrint.Enabled = aVal;
			#region Export
#if Export
			miSaveAsDXF.Enabled = aVal;
#endif
			#endregion
		}

		private void MainForm_Closed(object sender, System.EventArgs e)
		{
			#region protect
			#if protect
			this.cadViewerControl1.Unregister();
			#endif
			#endregion
		}

		private void miOpenFile_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.ShowLoadFileDialog();
		}

		private void miSaveFile_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.SaveAsImage();
		}

		private void miPrint_Click(object sender, System.EventArgs e)
		{
			if(cadViewerControl1.Image == null) 
				return;
			cadViewerControl1.Image.Print(true, true);
		}

		private void miCopy_Click(object sender, System.EventArgs e)
		{
			if(cadViewerControl1.Image == null) 
			 return;
			CADImport.DRect tmpRect = new CADImport.DRect(0, 0, cadViewerControl1.ClientRectangle.Width * cadViewerControl1.ImageScale, 
														  cadViewerControl1.ClientRectangle.Height*cadViewerControl1.ImageScale);
			cadViewerControl1.Image.SaveImageToClipboard(tmpRect);
		}

		private void miEntities_Click(object sender, System.EventArgs e)
		{			
			cadViewerControl1.PropertyEntityPanelVisible = ! cadViewerControl1.PropertyEntityPanelVisible;
			this.miShowEntityTree.Checked = this.cadViewerControl1.EntityTreeVisible;
			cadViewerControl1.DoResize();
		}

		private void miExit_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void miRegister_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.RegistrationForm.ShowDialog();
		}

		private void miAbout_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.AboutForm.ShowDialog();
		}

		private void miFit_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.ResetScaling();
		}

		private void miZoomIn_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.DoZoomIn();
		}

		private void miZoomOut_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.DoZoomOut();
		}

		private void miSHXFonts_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.AddSHXPaths();
		}

		private void miColor_Click(object sender, System.EventArgs e)
		{
			this.miDrawNormalColor.Checked = true;
			this.miDrawBlackColor.Checked = false;
			cadViewerControl1.DoNormalColor();
			cadViewerControl1.ChangeControlState();
		}

		private void miBlack_Click(object sender, System.EventArgs e)
		{			
			this.miDrawNormalColor.Checked = false;
			this.miDrawBlackColor.Checked = true;
			cadViewerControl1.DoBlackColor();
			cadViewerControl1.ChangeControlState();
		}		

		private void miWhiteBack_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.White_Click();			
		}

		private void miBlackBack_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.Black_Click();			
		}

		private void miChangeBack_Click(object sender, System.EventArgs e)
		{
			cadViewerControl1.Color_Click();
			cadViewerControl1.ChangeControlState();
		}

		private void miShowLineWight_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.ChangeShowLineWeight(! this.cadViewerControl1.ShowLineWeight);			
		}

		private void miArcsSplit_Click(object sender, System.EventArgs e)
		{
			miArcsSplit.Checked = ! miArcsSplit.Checked;
			cadViewerControl1.UseWinEllipse();
			cadViewerControl1.ChangeControlState();
		}

		private void miDimShow_Click(object sender, System.EventArgs e)
		{			
			cadViewerControl1.ChangeDimensionsVisiblity(! this.cadViewerControl1.Image.DimensionsVisible);			
		}

		private void miTextsShow_Click(object sender, System.EventArgs e)
		{			
			cadViewerControl1.ChangeTextsVisiblity(! cadViewerControl1.TextVisible);			
		}

		private void miLayersShow_Click(object sender, System.EventArgs e)
		{
			if(cadViewerControl1.Image == null) 
				return;
			cadViewerControl1.LayerForm.ShowDialog();
		}		

		private void CreateNewSettingsList()
		{
			string tmp; 
			settingsLst = new SortedList();
			//Language path
			settingsLst.Add(ApplicationConstants.languagepath, mlng.Path);
			//Language
			settingsLst.Add(ApplicationConstants.languagestr, lngFile);
			//Language ID
			settingsLst.Add(ApplicationConstants.languageIDstr, this.curLngIndex);
			//BackgroundColor
			if(cadViewerControl1.ViewerCADPictureBox.BackColor == Color.Black)
				tmp = ApplicationConstants.blackstr;
			else tmp = ApplicationConstants.whitestr;
			settingsLst.Add(ApplicationConstants.backcolorstr, tmp);
			//Show entity panel
			settingsLst.Add(ApplicationConstants.showentitystr, cadViewerControl1.EntityTreeVisible);
			//Color drawing
			if(this.cadViewerControl1.Image != null)
				settingsLst.Add(ApplicationConstants.colorDraw, (this.cadViewerControl1.Image.DrawMode == CADImport.CADDrawMode.Normal));
			else
				settingsLst.Add(ApplicationConstants.colorDraw, this.cadViewerControl1.ColorDraw);
			//SHXPathCount
			int cn = cadViewerControl1.SHXForm.lstDir.Items.Count;
			settingsLst.Add(ApplicationConstants.shxpathcnstr, cadViewerControl1.SHXForm.lstDir.Items.Count);
			//SHXPaths
			for(int i = 0; i < cn; i++)
			{
				settingsLst.Add("SHXPath_" + (i + 1), cadViewerControl1.SHXForm.lstDir.Items[i]);
			}
			this.cadViewerControl1.NewProtectionSettings(settingsLst);
		}	

		private void MainForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			CreateNewSettingsList();
			svSet.SaveOptions(settingsLst);
		}

		private void miSaveDXF_Click(object sender, System.EventArgs e)
		{
			if(this.cadViewerControl1.Image == null) return;
			if(this.saveDXFDlg.ShowDialog() != DialogResult.OK) return;
			this.cadViewerControl1.SaveAsDXF(this.saveDXFDlg.FileName);
		}		

		private void miFloatLic_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.FloatingRegistrationForm.ShowDialog();
		}

		private void miOptions_Click(object sender, System.EventArgs e)
		{	
			this.CreateNewSettingsList();		
			this.cadViewerControl1.OptionsForm.SettingsList = settingsLst;
			this.cadViewerControl1.OptionsForm.ShowDialog();			
		}

		private void miOpenFromWeb_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.ShowOpenFromWebForm();
		}		

		private void miClosePicture_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.CloseFile();
		}

		private void miSaveAsDXF_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SaveAsDXF();
		}

		private void miCustomPrint_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.PrintingForm.ShowDialog();
		}

		private void miPrintPreview_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.PrintingForm.TypePage = CADImport.Printing.DrawingSize.Fit;						
			this.cadViewerControl1.PrintPreviewDialog.Document = this.cadViewerControl1.PrintingForm.Print(false);				
			this.cadViewerControl1.PrintPreviewDialog.ShowDialog();
			if(this.cadViewerControl1.PrintPreviewDialog.Document != null)
				this.cadViewerControl1.PrintPreviewDialog.Document.Dispose();
					
		}

		private void miEnable3DOrbit_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.Enable3DOrbit();
		}

		private void miInitialView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetInitialView();
		}

		private void miTopView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetTopView();
		}

		private void miBottomView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetBottomView();
		}

		private void miLeftView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetLeftView();
		}

		private void miRightView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetRightView();
		}

		private void miFrontView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetFrontView();
		}

		private void miBackView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetBackView();
		}

		private void miSWIsometricView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetSWIsometricView();
		}

		private void miSEIsometricView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetSEIsometricView();
		}

		private void miNEIsometricView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetNEIsometricView();
		}

		private void miNWIsometricView_Click(object sender, System.EventArgs e)
		{
			this.cadViewerControl1.SetNWIsometricView();
		}		
	}
	
	internal abstract class ApplicationConstants
	{
		public static readonly string defaultstr;
		public static readonly string languagepath;		
		public static readonly string msgBoxDebugCaption;
		public static readonly string sepstr;
		public static readonly string notsupportedstr;
		public static readonly string notsupportedextstr;
		public static readonly string appnamestr;
		public static readonly string sepstr2;							
		public static readonly string lngextstr;
		public static readonly string languagestr;
		public static readonly string languageIDstr;
		public static readonly string backcolorstr;
		public static readonly string blackstr;
		public static readonly string showentitystr;
		public static readonly string drawmodestr;
		public static readonly string truestr;
		public static readonly string shxpathcnstr;
		public static readonly string installstr;
		public static readonly string sepstr3;
		public static readonly string typelcstr;
		public static readonly string floatingstr;
		public static readonly string hoststr;
		public static readonly string portstr;
		public static readonly string appconst;
		public static readonly string blackstr2;
		public static readonly string whitestr;
		public static readonly string registerstr;		
		public static readonly string namestr;
		public static readonly string visiblestr;
		public static readonly string freezestr;
		public static readonly string colorstr;		
		public static readonly string colorDraw;

		static ApplicationConstants()
		{
			defaultstr = "Default";
			languagepath = "LanguagePath";			
			msgBoxDebugCaption = "Debug application message";
			sepstr = " - ";
			notsupportedstr = "not supported";
			notsupportedextstr = "Not supported in current version!";
			appnamestr = "CADImportNet Demo";
			sepstr2 = " : ";						
			lngextstr = ".lng";
			languagestr = "Language";
			languageIDstr = "LanguageID";
			backcolorstr = "BackgroundColor";
			blackstr = "BLACK";
			showentitystr = "ShowEntity";
			drawmodestr = "drawMode";
			truestr = "TRUE";
			shxpathcnstr = "SHXPathCount";
			installstr = "Install";
			sepstr3 = ";";
			typelcstr = "Type_license";
			floatingstr = "floating";
			hoststr = "Host";
			portstr = "Port";
			appconst = "Application";
			blackstr2 = "Black";
			whitestr = "White";
			registerstr = "register";			
			namestr = "Name";
			visiblestr = "Visible";
			freezestr = "Freeze";
			colorstr = "Color";			
			colorDraw = "ColorDraw";
		}
	}
}
